/* ===========================================================================
 * $RCSfile: VerbNameMaker.java,v $
 * ===========================================================================
 *
 * RetroGuard -- an obfuscation package for Java classfiles.
 *
 * Copyright (c) 1998-2005 Mark Welsh (markw@retrologic.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * The author may be contacted at markw@retrologic.com
 *
 */

package COM.rl.obf;

import java.io.*;
import java.util.*;
import COM.rl.util.*;

/**
 * Name generator that uses a random list of English verbs to substitute as
 * names of Java class methods. English verbs were gathered from:
 *   http://www.verba.org/
 * Also, only verbs 6 chars and longer were used.
 *
 * @author      Mike Melanson (mike at multimedia.cx)
 */
public class VerbNameMaker extends NameMaker
{
    // Constants -------------------------------------------------------------
    private static final int randomSeed = 6;


    // Fields ----------------------------------------------------------------
    private int skipped = 0; // Names skipped in the sequence
    private Vector namesToDate = new Vector();
    private Hashtable argCount = new Hashtable();
    private String[] noObfNames = null; // List of names not to be obfuscated
    private String[] keywordsToUse;
    private String[] keywordsToExclude;
    private String[] firstLetter;
    private String[] nextLetter;
    private String[] noKeywords = {};
    Random generator = new Random(randomSeed);
    int theCount = 0;

    // Class Methods ---------------------------------------------------------
    /** Main method for testing. */
/*
    public static void main(String[] args) throws Exception
    {
        PrintWriter pw = new PrintWriter(
            new BufferedOutputStream(
                new FileOutputStream("VerbNameMaker.tst")));
        try
        {
            NameMaker nmk = new VerbNameMaker();
            for (int i = 0; i < 1000000; i++)
            {
                pw.println(nmk.nextName(null));
            }
        }
        finally
        {
            pw.close();
        }
    }
*/

    // Instance Methods ------------------------------------------------------
    /** Ctor. */
    public VerbNameMaker()
    {
        this(null);
    }

    /** Ctor - block names not to be obfuscated from the mapping target space. */
    public VerbNameMaker(String[] noObfNames)
    {
        this(noObfNames, true);
    }

    /** Ctor - block names not to be obfuscated from the mapping target space. */
    public VerbNameMaker(String[] noObfNames, boolean useKeywords)
    {
        this(noObfNames, true, false);
    }

    /** Ctor - block names not to be obfuscated from the mapping target space. */
    public VerbNameMaker(String[] noObfNames, boolean useKeywords, boolean lowerCaseOnly)
    {
        this.noObfNames = noObfNames == null ? new String[0] : noObfNames;
    }

    /** Return the next unique name for this namespace. */
    private static int num = 0;
    protected String getNextName(String oldName, String descriptor) throws Exception
    {
    	System.out.println("func: " + oldName + "|" + descriptor);
    	return "func_" + (++num) + "_" + oldName;
        //return getName(theCount++);
    }

    // Extract the arg-list from a descriptor
    private String getArgList(String descriptor) throws Exception
    {
        int pos = descriptor.indexOf(')');
        return descriptor.substring(1, pos);
    }

    // Generate i'th allowed, unique name
    private String getName(int index) throws Exception
    {
        // If we have previously computed this name, just return it
        String name = null;
        if (index < namesToDate.size())
        {
            name = (String)namesToDate.elementAt(index);
        }
        else
        {
            // Generate a new valid name for the sequence
            for (;;)
            {
                name = getNewName(index + skipped);
                if (!Tools.isInArray(name, noObfNames) ||
                    //(index + skipped < keywordsToUse.length ||
                     !Tools.isInArray(name, keywordsToExclude))
                {
                    break;
                }
                skipped++;
            }
            namesToDate.addElement(name);
        }
        return name;
    }

    // Generate j'th name in sequence (can repeat keywords)
    private String getNewName(int index) throws Exception
    {
        String name = null;
        name = englishVerbs[generator.nextInt(englishVerbs.length)];
        return name;
    }

    private String[] englishVerbs = {
        "abandon",
        "abbreviate",
        "abdicate",
        "abduct",
        "abjure",
        "abnegate",
        "abolish",
        "abominate",
        "abound",
        "abrade",
        "abreact",
        "abridge",
        "abrogate",
        "abscond",
        "absolve",
        "absorb",
        "absquatulate",
        "abstain",
        "abstract",
        "abutOn",
        "accede",
        "accent",
        "accentuate",
        "accept",
        "accessorize",
        "acclaim",
        "acclimate",
        "acclimatize",
        "accommodate",
        "accomodate",
        "accompany",
        "accomplish",
        "accost",
        "account",
        "accouter",
        "accredit",
        "accrete",
        "accrue",
        "accumulate",
        "accuse",
        "accustom",
        "acerbate",
        "acetify",
        "acetylate",
        "achieve",
        "achromatize",
        "acidify",
        "acidulate",
        "acknowledge",
        "acquaint",
        "acquiesce",
        "acquire",
        "acquit",
        "activate",
        "actuate",
        "addUpTo",
        "addict",
        "address",
        "adduce",
        "adduct",
        "adhere",
        "adhibit",
        "adjoin",
        "adjourn",
        "adjudge",
        "adjudicate",
        "adjure",
        "adjust",
        "admeasure",
        "administer",
        "administrate",
        "admire",
        "admonish",
        "adrenalize",
        "adsorb",
        "adulate",
        "adulterate",
        "adumbrate",
        "advance",
        "advect",
        "advert",
        "advertise",
        "advise",
        "aerate",
        "aerobicize",
        "aestheticize",
        "aestivate",
        "affect",
        "affiance",
        "affiliate",
        "affirm",
        "afflict",
        "afford",
        "afforest",
        "agglutinate",
        "aggrade",
        "aggrandize",
        "aggravate",
        "aggregate",
        "aggress",
        "aggrieve",
        "agitate",
        "agonize",
        "airCondition",
        "airCool",
        "alchemize",
        "alienate",
        "alight",
        "aliment",
        "alkylate",
        "allege",
        "alleviate",
        "allign",
        "allocate",
        "allude",
        "allure",
        "alphabetize",
        "altercate",
        "alternate",
        "aluminize",
        "amalgamate",
        "ambulate",
        "ameliorate",
        "amerce",
        "ammonify",
        "amortize",
        "amplify",
        "amputate",
        "anaesthetize",
        "anagrammatize",
        "analyse",
        "analyze",
        "anathematize",
        "anatomize",
        "anchor",
        "androgenize",
        "angleFor",
        "animadvert",
        "animalize",
        "ankylose",
        "annihilate",
        "annotate",
        "announce",
        "annualize",
        "annunciate",
        "anodize",
        "anoint",
        "answer",
        "answerBack",
        "answerFor",
        "answerTo",
        "antagonize",
        "antecede",
        "antedate",
        "anticipate",
        "antiquate",
        "aphorize",
        "apologise",
        "apologize",
        "apostatize",
        "apostrophize",
        "apotheosize",
        "appall",
        "appeal",
        "appealTo",
        "appear",
        "appease",
        "append",
        "apperceive",
        "appertain",
        "applaud",
        "appoint",
        "apportion",
        "appose",
        "appraise",
        "appreciate",
        "apprise",
        "apprize",
        "approach",
        "approbate",
        "appropriate",
        "approve",
        "approximate",
        "arbitrate",
        "arborize",
        "archive",
        "armWrestle",
        "aroint",
        "aromatize",
        "arouse",
        "arraign",
        "arrange",
        "arrest",
        "arrive",
        "arrogate",
        "arterialize",
        "articulate",
        "ascend",
        "ascertain",
        "ascribe",
        "asperate",
        "asperse",
        "asphyxiate",
        "aspirate",
        "aspire",
        "assail",
        "assassinate",
        "assault",
        "assemble",
        "assent",
        "assert",
        "assess",
        "asseverate",
        "assibilate",
        "assign",
        "assimilate",
        "assist",
        "associate",
        "assoil",
        "assuage",
        "assume",
        "assure",
        "astonish",
        "astound",
        "astrogate",
        "atomize",
        "atrophy",
        "attach",
        "attack",
        "attain",
        "attempt",
        "attend",
        "attenuate",
        "attest",
        "attitudinize",
        "attorn",
        "attract",
        "attribute",
        "attrit",
        "attune",
        "auction",
        "augment",
        "auscultate",
        "ausform",
        "auspicate",
        "authenticate",
        "author",
        "authorise",
        "authorize",
        "autoDestruct",
        "automate",
        "automatize",
        "avenge",
        "average",
        "aviate",
        "avouch",
        "avulse",
        "awaken",
        "babble",
        "backAway",
        "backDown",
        "backOff",
        "backOnto",
        "backOut",
        "backUp",
        "backfire",
        "backlight",
        "backstab",
        "bacterize",
        "badmouth",
        "baffle",
        "balance",
        "balkanize",
        "ballot",
        "bamboozle",
        "banish",
        "banner",
        "baptize",
        "barbarize",
        "bargain",
        "bargeIn",
        "bargeOut",
        "barrack",
        "barricade",
        "baseJump",
        "basify",
        "bastardize",
        "batfowl",
        "batten",
        "battle",
        "bearUp",
        "beatDown",
        "beatify",
        "beautify",
        "bebriend",
        "becloud",
        "become",
        "bedeck",
        "bedevil",
        "bedight",
        "bedizen",
        "bedraggle",
        "befall",
        "befool",
        "befoul",
        "befriend",
        "befuddle",
        "begrime",
        "begrudge",
        "beguile",
        "behave",
        "behead",
        "behold",
        "belabor",
        "belabour",
        "beleaguer",
        "believe",
        "belittle",
        "bellow",
        "bellyLand",
        "belong",
        "bemire",
        "bemoan",
        "benchPress",
        "benumb",
        "bequeath",
        "berate",
        "bereave",
        "beseech",
        "beshrew",
        "besiege",
        "besmear",
        "besmirch",
        "bespatter",
        "bespeak",
        "bestow",
        "bestride",
        "betake",
        "bethink",
        "betoken",
        "betray",
        "betroth",
        "bewail",
        "bewilder",
        "bewitch",
        "bewray",
        "bifurcate",
        "billet",
        "bituminize",
        "blackFlag",
        "blackMarket",
        "blackOut",
        "blacken",
        "blackmail",
        "blackwash",
        "blandify",
        "blandish",
        "blankOut",
        "blanketStitch",
        "blaspheme",
        "bleach",
        "blench",
        "blindSide",
        "blither",
        "blossom",
        "blotOut",
        "blotUp",
        "blowDown",
        "blowDry",
        "blowOver",
        "blowUp",
        "bluePencil",
        "bodysurf",
        "boilDown",
        "bollix",
        "bolsterUp",
        "bombard",
        "borrow",
        "bother",
        "bottleFeed",
        "bounce",
        "bourgeoisify",
        "bowdlerize",
        "bowlOver",
        "boxhaul",
        "boycott",
        "braise",
        "branch",
        "branchOff",
        "branchOut",
        "brandish",
        "breakAway",
        "breakDown",
        "breakFor",
        "breakIn",
        "breakInto",
        "breakOf",
        "breakOff",
        "breakOut",
        "breakUp",
        "breakWith",
        "breastFeed",
        "breathe",
        "brecciate",
        "brewUp",
        "bridle",
        "brighten",
        "bringAbout",
        "bringBack",
        "bringDown",
        "bringForth",
        "bringForward",
        "bringIn",
        "bringOff",
        "bringOn",
        "bringOut",
        "bringRound",
        "bringThrough",
        "bringTogether",
        "bringUp",
        "bringUpon",
        "broach",
        "broadcast",
        "broaden",
        "broider",
        "brominate",
        "broodAbout",
        "broodOn",
        "broodOver",
        "browbeat",
        "brownNose",
        "browse",
        "bruise",
        "brutalise",
        "brutalize",
        "buildInto",
        "buildUnder",
        "buildUp",
        "bullyrag",
        "bumfuzzle",
        "bumpInto",
        "bumpOff",
        "bumpUp",
        "bundle",
        "bungle",
        "burble",
        "burden",
        "bureaucratize",
        "burgeon",
        "burglarise",
        "burglarize",
        "burgle",
        "burnish",
        "burnish",
        "bushel",
        "buttWeld",
        "butylate",
        "bypass",
        "cachinnate",
        "cajole",
        "calcify",
        "calculate",
        "calibrate",
        "callBack",
        "callDown",
        "callFor",
        "callOn",
        "callate",
        "calumniate",
        "camouflage",
        "camphorate",
        "canalize",
        "cancel",
        "cancell",
        "cannibalize",
        "cannot",
        "canonize",
        "cantillate",
        "canvass",
        "capacitate",
        "caparison",
        "capitalize",
        "capitulate",
        "capsize",
        "capsulize",
        "captivate",
        "capture",
        "caramelize",
        "carbonise",
        "carbonize",
        "carburet",
        "carburize",
        "careFor",
        "careen",
        "carjack",
        "carpetBomb",
        "carryForward",
        "carryOff",
        "carryOn",
        "carryOut",
        "carryOver",
        "carryThrough",
        "carveOut",
        "carveUp",
        "caseHarden",
        "caseate",
        "cashier",
        "castigate",
        "castrate",
        "catabolize",
        "catalog",
        "catalogue",
        "catalyze",
        "catapult",
        "catchUp",
        "catechize",
        "categorise",
        "categorize",
        "catenate",
        "caterwaul",
        "cathect",
        "catheterize",
        "catholicize",
        "cauterise",
        "cauterize",
        "caveIn",
        "cavort",
        "celebrate",
        "censor",
        "center",
        "centralise",
        "centralize",
        "centre",
        "cerebrate",
        "certificate",
        "certify",
        "chainReact",
        "challenge",
        "chance",
        "change",
        "changeOver",
        "channelize",
        "characterize",
        "charbroil",
        "charge",
        "charter",
        "chasten",
        "chastise",
        "chatter",
        "cheapen",
        "checkOn",
        "cheerUp",
        "cheerlead",
        "cheese",
        "chemisorb",
        "chemosorb",
        "cherish",
        "chipper",
        "chirrup",
        "chitter",
        "chlorinate",
        "choose",
        "chopOff",
        "christen",
        "christianize",
        "cicatrize",
        "cinematize",
        "circularise",
        "circularize",
        "circulate",
        "circumambulate",
        "circumcise",
        "circumfuse",
        "circumnavigate",
        "circumrotate",
        "circumscribe",
        "circumstantiate",
        "circumvent",
        "circumvolve",
        "citify",
        "civilianize",
        "civilise",
        "civilize",
        "clarify",
        "classify",
        "cleanOut",
        "cleanUp",
        "cleanse",
        "clearOut",
        "cleave",
        "clench",
        "clickOn",
        "climbDown",
        "clinch",
        "clobber",
        "clockIn",
        "clothe",
        "cluster",
        "clutch",
        "coOperate",
        "coWrite",
        "coagulate",
        "coalesce",
        "coarsen",
        "cobble",
        "cocainize",
        "cocker",
        "coddle",
        "codeName",
        "codify",
        "codirect",
        "coedit",
        "coerce",
        "coexist",
        "coextend",
        "cofound",
        "cogitate",
        "cohabit",
        "coincide",
        "coinsure",
        "coldWeld",
        "coldcock",
        "coldshoulder",
        "collaborate",
        "collapse",
        "collate",
        "collateralize",
        "collect",
        "collectivize",
        "collide",
        "colligate",
        "collimate",
        "collocate",
        "collogue",
        "collude",
        "colonize",
        "colorCode",
        "colorbreed",
        "colorize",
        "colour",
        "combine",
        "comeAbout",
        "comeAcross",
        "comeBack",
        "comeDown",
        "comeFrom",
        "comeOut",
        "comeRound",
        "comeUp",
        "command",
        "commandeer",
        "commemorate",
        "commend",
        "comment",
        "commercialise",
        "commercialize",
        "comminute",
        "commiserate",
        "commission",
        "commit",
        "commove",
        "communalize",
        "communicate",
        "commutate",
        "commute",
        "compare",
        "comparisonShop",
        "compart",
        "compartmentalize",
        "compel",
        "compensate",
        "compete",
        "compile",
        "complain",
        "complect",
        "complete",
        "complicate",
        "comply",
        "compose",
        "compound",
        "comprehend",
        "compress",
        "comprise",
        "compromise",
        "compute",
        "computerise",
        "computerize",
        "concatenate",
        "conceal",
        "concede",
        "conceive",
        "concenter",
        "concentrate",
        "concern",
        "concertize",
        "conciliate",
        "conclude",
        "concoct",
        "concretize",
        "concur",
        "concuss",
        "condemn",
        "condense",
        "condescend",
        "condition",
        "condole",
        "condone",
        "conduce",
        "conduct",
        "confabulate",
        "confederate",
        "confer",
        "confess",
        "confide",
        "configure",
        "confine",
        "confirm",
        "confiscate",
        "conflate",
        "conform",
        "confound",
        "confront",
        "confuse",
        "confute",
        "congeal",
        "conglobate",
        "conglobe",
        "conglomerate",
        "congratulate",
        "congregate",
        "conjoin",
        "conjugate",
        "conjure",
        "connect",
        "connive",
        "connote",
        "conquer",
        "consecrate",
        "consent",
        "conservatize",
        "conserve",
        "consider",
        "consign",
        "consist",
        "console",
        "consolidate",
        "conspire",
        "constellate",
        "consternate",
        "constipate",
        "constitute",
        "constitutionalize",
        "constrain",
        "constrict",
        "constringe",
        "construct",
        "construe",
        "consubstantiate",
        "consult",
        "consume",
        "consummate",
        "contact",
        "contain",
        "contemn",
        "contemplate",
        "contend",
        "contest",
        "contextualize",
        "continue",
        "contradict",
        "contradistinguish",
        "contraindicate",
        "contravene",
        "contribute",
        "contrive",
        "control",
        "controvert",
        "contuse",
        "convalesce",
        "convene",
        "conventionalize",
        "converge",
        "converse",
        "convert",
        "convey",
        "convict",
        "convince",
        "convoke",
        "convulse",
        "coolOff",
        "cooperate",
        "coordinate",
        "coppice",
        "copulate",
        "coquet",
        "cornbraid",
        "corner",
        "cornify",
        "cornrow",
        "corotate",
        "corrade",
        "correct",
        "correspond",
        "corroborate",
        "corrode",
        "coruscate",
        "cosign",
        "cosmeticize",
        "cosset",
        "counterAttack",
        "counteract",
        "counterchange",
        "counterfeit",
        "countermand",
        "counterpose",
        "countersign",
        "countersink",
        "countersue",
        "counterweigh",
        "couple",
        "covenant",
        "coverUp",
        "crackle",
        "crankUp",
        "crashDive",
        "create",
        "credit",
        "cremate",
        "crepitate",
        "criminalize",
        "criminate",
        "cringe",
        "crinkle",
        "cripple",
        "crisscross",
        "criticise",
        "criticize",
        "cropUp",
        "crossDress",
        "crossFertilize",
        "crossFile",
        "crossMultiply",
        "crossPollinate",
        "crossbreed",
        "crucify",
        "crumble",
        "crumbleAway",
        "crunch",
        "cryOut",
        "cryopreserve",
        "cryptanalyze",
        "crystalize",
        "crystallise",
        "crystallize",
        "cuddle",
        "cudgel",
        "cuittle",
        "cultivate",
        "curarize",
        "curate",
        "curdle",
        "curlUp",
        "curtail",
        "cushion",
        "custom",
        "customize",
        "cutAcross",
        "cutAway",
        "cutBack",
        "cutDown",
        "cutOff",
        "cutOut",
        "damage",
        "dampen",
        "dandify",
        "dapple",
        "daresay",
        "darken",
        "dawdle",
        "dazzle",
        "deEmphasize",
        "deacidify",
        "deactivate",
        "deafen",
        "dealIn",
        "dealOut",
        "dealWith",
        "dealcoholize",
        "deaminate",
        "deaminize",
        "deathQualify",
        "debase",
        "debate",
        "debilitate",
        "debone",
        "debrief",
        "debunk",
        "decamp",
        "decant",
        "decapitate",
        "decarbonate",
        "decarbonize",
        "decarburize",
        "deceive",
        "decelerate",
        "decentralize",
        "decertify",
        "decide",
        "decimalize",
        "decimate",
        "decipher",
        "deckOut",
        "declaim",
        "declare",
        "declass",
        "declassify",
        "declaw",
        "decline",
        "decoct",
        "decode",
        "decollate",
        "decollectivize",
        "decolonize",
        "decolorize",
        "decommission",
        "decompose",
        "decompound",
        "decompress",
        "deconcentrate",
        "decongest",
        "deconsecrate",
        "deconstruct",
        "decontaminate",
        "decontrol",
        "decorate",
        "decorticate",
        "decouple",
        "decrease",
        "decree",
        "decriminalize",
        "dedicate",
        "deduce",
        "deduct",
        "deepFreeze",
        "deepFry",
        "deepSix",
        "deepen",
        "deface",
        "defalcate",
        "defame",
        "defang",
        "default",
        "defeat",
        "defecate",
        "defeminize",
        "defend",
        "defenestrate",
        "defibrillate",
        "defile",
        "define",
        "deflagrate",
        "deflate",
        "deflect",
        "deflower",
        "defoam",
        "defoliate",
        "deforce",
        "deforest",
        "deform",
        "defraud",
        "defray",
        "defrock",
        "defrost",
        "defuel",
        "defund",
        "defuse",
        "degauss",
        "degenerate",
        "deglamorize",
        "deglaze",
        "deglutinate",
        "degrade",
        "degrease",
        "degust",
        "dehire",
        "dehisce",
        "dehorn",
        "dehumanize",
        "dehumidify",
        "dehydrate",
        "dehydrochlorinate",
        "dehydrogenate",
        "dehydrogenize",
        "dehypnotize",
        "deinstitutionalize",
        "deionize",
        "deject",
        "delaminate",
        "delegalize",
        "delegate",
        "delegitimize",
        "delimit",
        "delineate",
        "deliquesce",
        "delist",
        "deliver",
        "delocalize",
        "delouse",
        "delude",
        "demagnetize",
        "demand",
        "demarcate",
        "dematerialize",
        "demean",
        "dement",
        "demilitarise",
        "demilitarize",
        "demineralize",
        "demise",
        "demobilise",
        "demobilize",
        "democratize",
        "demodulate",
        "demolish",
        "demonetize",
        "demonize",
        "demonstrate",
        "demoralize",
        "demote",
        "demount",
        "demyelinate",
        "demystify",
        "demythologize",
        "denationalise",
        "denationalize",
        "denaturalize",
        "denature",
        "denervate",
        "denigrate",
        "denitrify",
        "denominate",
        "denote",
        "denounce",
        "denude",
        "deodorise",
        "deodorize",
        "deoxidate",
        "deoxidize",
        "deoxygenate",
        "depart",
        "departmentalize",
        "depend",
        "depersonalize",
        "depict",
        "depilate",
        "deplane",
        "deplete",
        "deplore",
        "deploy",
        "deplume",
        "depolarize",
        "depoliticize",
        "depollute",
        "depopulate",
        "deport",
        "depose",
        "deposit",
        "deprave",
        "deprecate",
        "depreciate",
        "depress",
        "deprive",
        "deprogram",
        "depurate",
        "depute",
        "deputise",
        "deputize",
        "deracinate",
        "derail",
        "derange",
        "derecognize",
        "deregulate",
        "derepress",
        "deride",
        "derive",
        "desacralize",
        "desalinate",
        "desalinize",
        "desalt",
        "descant",
        "descend",
        "descramble",
        "describe",
        "descry",
        "desecrate",
        "deselect",
        "desensitise",
        "desensitize",
        "desert",
        "deserve",
        "desexualize",
        "desiderate",
        "design",
        "designate",
        "desire",
        "desist",
        "deskill",
        "desorb",
        "despair",
        "despatch",
        "despise",
        "despoil",
        "desquamate",
        "destabilize",
        "destain",
        "desterilize",
        "destine",
        "destroy",
        "desulfurize",
        "detach",
        "detain",
        "detect",
        "deterge",
        "deteriorate",
        "determine",
        "detest",
        "dethrone",
        "detonate",
        "detoxicate",
        "detoxify",
        "detrain",
        "detribalize",
        "deuterate",
        "devalue",
        "devastate",
        "develop",
        "devest",
        "deviate",
        "devise",
        "devitalize",
        "devitrify",
        "devocalize",
        "devoice",
        "devolatize",
        "devote",
        "devour",
        "dewater",
        "deworm",
        "diabolize",
        "diagnose",
        "dialIn",
        "dialyze",
        "dictate",
        "diddle",
        "dieAway",
        "dieBack",
        "dieDown",
        "dieOff",
        "dieOut",
        "differ",
        "differentiate",
        "diffract",
        "diffuse",
        "digOut",
        "digitalize",
        "digitise",
        "digitize",
        "dignify",
        "digress",
        "dilapidate",
        "dilate",
        "dillyDally",
        "dilute",
        "diphthongize",
        "direct",
        "disable",
        "disabuse",
        "disaccustom",
        "disaffect",
        "disaffirm",
        "disagree",
        "disallow",
        "disambiguate",
        "disannul",
        "disappear",
        "disappoint",
        "disapprove",
        "disarm",
        "disarrange",
        "disassociate",
        "disavow",
        "disbar",
        "disbelieve",
        "disbranch",
        "disbud",
        "disburse",
        "discard",
        "discern",
        "discharge",
        "discipline",
        "disclaim",
        "disclose",
        "discolour",
        "discombobulate",
        "discommend",
        "discommode",
        "discompose",
        "disconcert",
        "disconnect",
        "disconnet",
        "discontent",
        "discontinue",
        "discount",
        "discourage",
        "discover",
        "discredit",
        "discriminate",
        "discuss",
        "disembark",
        "disembarrass",
        "disembody",
        "disembowel",
        "disemploy",
        "disempower",
        "disenable",
        "disenchant",
        "disencumber",
        "disendow",
        "disenfranchise",
        "disengage",
        "disentail",
        "disentangle",
        "disenthrall",
        "disentomb",
        "disentwine",
        "disequilibrate",
        "disestablish",
        "disfavour",
        "disfeature",
        "disfigure",
        "disfranchise",
        "disfrock",
        "disgorge",
        "disgrace",
        "disgruntle",
        "disguise",
        "disgust",
        "disharmonize",
        "dishearten",
        "dishevel",
        "dishonor",
        "dishonour",
        "disincorporate",
        "disinfect",
        "disinfest",
        "disinform",
        "disinherit",
        "disinhibit",
        "disinter",
        "disintoxicate",
        "disinvent",
        "disinvite",
        "dislike",
        "dislocate",
        "dislodge",
        "dismantle",
        "dismast",
        "dismember",
        "dismiss",
        "dismount",
        "disobey",
        "disoblige",
        "disorganize",
        "disorient",
        "disorientate",
        "disown",
        "disparage",
        "dispel",
        "dispense",
        "dispeople",
        "disperse",
        "dispirit",
        "displace",
        "display",
        "display",
        "displease",
        "displode",
        "dispose",
        "disposeOf",
        "dispossess",
        "disprize",
        "disprove",
        "dispute",
        "disqualify",
        "disrate",
        "disregard",
        "disrobe",
        "disrupt",
        "dissatisfy",
        "disseat",
        "dissect",
        "disseise",
        "disseize",
        "dissemble",
        "disseminate",
        "dissent",
        "dissertate",
        "disserve",
        "dissimulate",
        "dissipate",
        "dissolve",
        "dissuade",
        "distend",
        "distil",
        "distinguish",
        "distort",
        "distract",
        "distress",
        "distribute",
        "distrust",
        "disturb",
        "disunite",
        "dither",
        "divagate",
        "diveBomb",
        "diverge",
        "diversify",
        "divert",
        "divest",
        "divide",
        "divorce",
        "divulge",
        "dodder",
        "dognap",
        "domesticate",
        "domesticize",
        "dominate",
        "donate",
        "double",
        "doublePark",
        "doubleSpace",
        "doubleTeam",
        "doubleTime",
        "doubleTongue",
        "dovetail",
        "downgrade",
        "download",
        "drabble",
        "dramatise",
        "dramatize",
        "drawBack",
        "drawIn",
        "drawInto",
        "drawOff",
        "drawOn",
        "drawOut",
        "drawUp",
        "dredge",
        "dredgeUp",
        "drench",
        "driftApart",
        "driftOff",
        "drinkIn",
        "drinkUp",
        "driveAt",
        "driveAway",
        "driveBack",
        "driveOff",
        "driveOut",
        "driveUp",
        "drivel",
        "drudge",
        "dryClean",
        "dryDock",
        "dryOff",
        "dryOut",
        "dulcify",
        "dumbfound",
        "dumfound",
        "dumfounder",
        "duplicate",
        "dwindle",
        "earmark",
        "eavesdrop",
        "ebbAway",
        "ebonize",
        "economise",
        "economize",
        "editorialize",
        "educate",
        "efface",
        "effectuate",
        "effervesce",
        "effloresce",
        "egoTrip",
        "eightySix",
        "ejaculate",
        "elaborate",
        "elapse",
        "electioneer",
        "electrify",
        "electrocute",
        "electroform",
        "electrolyze",
        "electrophorese",
        "electroplate",
        "elevate",
        "elicit",
        "eliminate",
        "eloign",
        "elutriate",
        "eluviate",
        "emaciate",
        "emanate",
        "emancipate",
        "emasculate",
        "embalm",
        "embank",
        "embarass",
        "embark",
        "embarrass",
        "embattle",
        "embellish",
        "embezzle",
        "embitter",
        "emblaze",
        "emblazon",
        "emblematize",
        "emblemize",
        "embody",
        "embolden",
        "embosom",
        "emboss",
        "embowel",
        "embower",
        "embrace",
        "embrangle",
        "embrittle",
        "embrocate",
        "embroil",
        "embrown",
        "embrue",
        "emerge",
        "emigrate",
        "emotionalize",
        "empanel",
        "empathize",
        "emphasize",
        "emplace",
        "emplane",
        "employ",
        "empoison",
        "empower",
        "empurple",
        "emulate",
        "emulate",
        "emulsify",
        "enable",
        "enamor",
        "enamour",
        "encage",
        "encapsulate",
        "encapsule",
        "encase",
        "enchain",
        "enchant",
        "enchase",
        "encipher",
        "encircle",
        "enclasp",
        "enclose",
        "encode",
        "encompass",
        "encounter",
        "encourage",
        "encroach",
        "encrust",
        "encrypt",
        "encumber",
        "endRun",
        "endanger",
        "endear",
        "endeavour",
        "endorse",
        "endure",
        "energize",
        "enervate",
        "enface",
        "enfeeble",
        "enfeoff",
        "enfetter",
        "enfold",
        "enforce",
        "enfranchise",
        "engage",
        "engarland",
        "engender",
        "engird",
        "engirdle",
        "engirt",
        "englut",
        "engraft",
        "engrain",
        "engrave",
        "engross",
        "engulf",
        "enhance",
        "enisle",
        "enjoin",
        "enlace",
        "enlarge",
        "enlighten",
        "enlist",
        "enliven",
        "enmesh",
        "ennoble",
        "enounce",
        "enplane",
        "enquire",
        "enrage",
        "enrapture",
        "enrich",
        "enrobe",
        "enroll",
        "enroot",
        "ensanguine",
        "ensconce",
        "enshrine",
        "enshroud",
        "ensile",
        "enslave",
        "ensnare",
        "ensnarl",
        "ensoul",
        "ensphere",
        "ensure",
        "entail",
        "entangle",
        "entertain",
        "enthrall",
        "enthrone",
        "entice",
        "entitle",
        "entoil",
        "entomb",
        "entrain",
        "entrance",
        "entrap",
        "entreat",
        "entrust",
        "entwine",
        "entwist",
        "enumerate",
        "enunciate",
        "envelop",
        "envenom",
        "environ",
        "envisage",
        "envision",
        "enwind",
        "enwomb",
        "enwrap",
        "enwreathe",
        "epithelize",
        "epitomize",
        "equalise",
        "equalize",
        "equate",
        "equilibrate",
        "equiponderate",
        "equivocate",
        "eradicate",
        "eroticize",
        "erotize",
        "escape",
        "eschew",
        "escort",
        "espouse",
        "establish",
        "esterify",
        "estheticize",
        "estimate",
        "estivate",
        "estrange",
        "eternalize",
        "eternize",
        "etherialize",
        "etherify",
        "etherize",
        "ethylate",
        "euhemerize",
        "eulogize",
        "euphonize",
        "europeanize",
        "euthanize",
        "evacuate",
        "evaginate",
        "evaluate",
        "evanesce",
        "evaporate",
        "eventuate",
        "evidence",
        "evince",
        "eviscerate",
        "evolve",
        "exacerbate",
        "exaggerate",
        "examine",
        "exasperate",
        "excavate",
        "exceed",
        "except",
        "exchange",
        "excise",
        "excite",
        "exclaim",
        "exclude",
        "excogitate",
        "excommunicate",
        "excoriate",
        "excrete",
        "excruciate",
        "exculpate",
        "excuse",
        "execrate",
        "execute",
        "exemplify",
        "exenterate",
        "exercise",
        "exhaust",
        "exhibit",
        "exhilarate",
        "exhume",
        "exibit",
        "exonerate",
        "exorcise",
        "expand",
        "expatiate",
        "expatriate",
        "expect",
        "expectorate",
        "expedite",
        "expend",
        "experiment",
        "expiate",
        "expire",
        "explain",
        "explicate",
        "explode",
        "exploit",
        "explore",
        "export",
        "expose",
        "expostulate",
        "express",
        "expropriate",
        "expunge",
        "expurgate",
        "exsanguinate",
        "exscind",
        "exsiccate",
        "extend",
        "extenuate",
        "exteriorize",
        "exterminate",
        "externalize",
        "extinguish",
        "extirpate",
        "extort",
        "extract",
        "extradite",
        "extravagate",
        "extricate",
        "extrude",
        "exuberate",
        "fabricate",
        "fabulate",
        "faceHarden",
        "facilitate",
        "factionalize",
        "factorize",
        "fadeAway",
        "fadeIn",
        "fadeOut",
        "fairTrade",
        "fallAbout",
        "fallApart",
        "fallAway",
        "fallBack",
        "fallBackOn",
        "fallBehind",
        "fallDown",
        "fallFor",
        "fallIn",
        "fallInBehind",
        "fallInWith",
        "fallInto",
        "fallOff",
        "fallOver",
        "fallTo",
        "fallTrough",
        "falsify",
        "falter",
        "familiarize",
        "fantasize",
        "fantasticate",
        "faradize",
        "farebeat",
        "farrow",
        "fascinate",
        "fastTalk",
        "fasten",
        "fasten",
        "fatten",
        "favour",
        "feather",
        "feature",
        "fecundate",
        "federalize",
        "federate",
        "feminize",
        "fendOff",
        "ferment",
        "fertilise",
        "fertilize",
        "fester",
        "festoon",
        "fetishize",
        "feudalize",
        "fiberize",
        "fibrillate",
        "fictionalize",
        "fictionize",
        "fieldTest",
        "fieldstrip",
        "figure",
        "figureOut",
        "filiate",
        "fillIn",
        "fillOut",
        "fillUp",
        "fillet",
        "filter",
        "finalize",
        "finance",
        "findGuilty",
        "fineTune",
        "fingerPaint",
        "finish",
        "finishOff",
        "finlandize",
        "fireAway",
        "fireBack",
        "fireOff",
        "fireUp",
        "firmUp",
        "fitOut",
        "fitWith",
        "fizzle",
        "fizzleOut",
        "flabbergast",
        "flagellate",
        "flatten",
        "flatter",
        "flaunt",
        "flavour",
        "flense",
        "fletch",
        "flightTest",
        "flinch",
        "flounder",
        "flourish",
        "flowChart",
        "fluctuate",
        "fluidize",
        "flummox",
        "fluoresce",
        "fluoridate",
        "flurry",
        "fluster",
        "flutter",
        "flyCast",
        "flyFish",
        "focalize",
        "follow",
        "foment",
        "fondle",
        "footslog",
        "forbear",
        "forbid",
        "forceFeed",
        "forceMarch",
        "foreCheck",
        "forearm",
        "forecast",
        "foreclose",
        "foredo",
        "foredoom",
        "forefeel",
        "forefend",
        "foregather",
        "forego",
        "forejudge",
        "foreknow",
        "foreordain",
        "forerun",
        "foresake",
        "foresee",
        "foreshadow",
        "foreshorten",
        "foreshow",
        "forespeak",
        "forestall",
        "foreswear",
        "foretell",
        "forewarn",
        "forfeit",
        "forfend",
        "forgather",
        "forget",
        "forgive",
        "forjudge",
        "formalise",
        "formalize",
        "format",
        "formularize",
        "formulate",
        "formulize",
        "fornicate",
        "forsake",
        "forswear",
        "fortify",
        "forward",
        "fossilize",
        "founder",
        "fourFlush",
        "foxtrot",
        "fractionalize",
        "fractionate",
        "fractionize",
        "fracture",
        "fragmentize",
        "fraternize",
        "freeAssociate",
        "freewheel",
        "freeze",
        "freezeDry",
        "french",
        "frenchFry",
        "frenchify",
        "frequent",
        "frighten",
        "fritter",
        "fritterAway",
        "frivol",
        "frustrate",
        "fulfil",
        "fulfill",
        "fulminate",
        "fulmine",
        "fumble",
        "fumigate",
        "furbish",
        "furnish",
        "fustigate",
        "gabble",
        "gadAbout",
        "gadAround",
        "gainsay",
        "galavant",
        "gallicize",
        "gallivant",
        "galumph",
        "galvanize",
        "gambol",
        "gammon",
        "gangpunch",
        "garble",
        "garnish",
        "garrotte",
        "gasify",
        "gastrulate",
        "gatecrash",
        "gather",
        "gelate",
        "generalize",
        "generate",
        "gentrify",
        "genuflect",
        "geologize",
        "geometricize",
        "germanize",
        "germinate",
        "gesticulate",
        "getAbout",
        "getAlong",
        "getAround",
        "getAroundTo",
        "getAway",
        "getAwayFrom",
        "getAwayWith",
        "getBack",
        "getBackAt",
        "getBackTo",
        "getBehind",
        "getDown",
        "getDownTo",
        "getInOn",
        "getInWith",
        "getInto",
        "getOff",
        "getOffOn",
        "getOffTo",
        "getOffWith",
        "getOnto",
        "getOut",
        "getOutOf",
        "getOver",
        "getRound",
        "getStuck",
        "getThere",
        "getThrough",
        "getThroughTo",
        "getTogether",
        "getUpTo",
        "ghettoize",
        "ghostWrite",
        "giggle",
        "gillnet",
        "giveAway",
        "giveBack",
        "giveBirth",
        "giveEvidence",
        "giveIn",
        "giveInTo",
        "giveOf",
        "giveOff",
        "giveOn",
        "giveOnto",
        "giveOut",
        "giveOver",
        "giveOverTo",
        "giveRise",
        "giveUp",
        "giveWay",
        "glaciate",
        "gladden",
        "glamorize",
        "glamourize",
        "glance",
        "glanceOff",
        "glimmer",
        "glimpse",
        "glisten",
        "glitter",
        "globalize",
        "globeTrot",
        "glorify",
        "glossOver",
        "glower",
        "goAbout",
        "goAfter",
        "goAgainst",
        "goAhead",
        "goAlong",
        "goAround",
        "goAway",
        "goBack",
        "goBankrupt",
        "goDown",
        "goInto",
        "goOver",
        "goRound",
        "goSlow",
        "goThrough",
        "goTogether",
        "goUnder",
        "gobble",
        "gobbleUp",
        "gooseStep",
        "gorgonize",
        "gothicize",
        "grabble",
        "graphitize",
        "grapple",
        "grappleWith",
        "gratify",
        "gratulate",
        "gravitate",
        "grease",
        "greaten",
        "grecize",
        "grieve",
        "grizzle",
        "grouch",
        "ground",
        "grovel",
        "grumble",
        "guarantee",
        "gulpDown",
        "gurgle",
        "gutturalize",
        "guzzle",
        "gyrate",
        "haggle",
        "halfSole",
        "hallow",
        "halogenate",
        "hamper",
        "hamstring",
        "handAround",
        "handBack",
        "handDown",
        "handIn",
        "handOn",
        "handOut",
        "handOver",
        "handle",
        "hangAround",
        "hangBack",
        "hangGlide",
        "hangOn",
        "hangOnTo",
        "hangOut",
        "hangOver",
        "hangRound",
        "hangTogether",
        "hangUp",
        "hanker",
        "happen",
        "harass",
        "hardBoil",
        "harden",
        "harken",
        "harmonise",
        "harmonize",
        "harness",
        "harrow",
        "harrumph",
        "harshen",
        "harvest",
        "hassle",
        "hasten",
        "haulOff",
        "haulUp",
        "haveOn",
        "haveSupper",
        "haveTo",
        "headhunt",
        "healOver",
        "healUp",
        "heapUp",
        "hearten",
        "heatSeal",
        "heatThrough",
        "heatTreat",
        "heatUp",
        "hebetate",
        "heckle",
        "hedgehop",
        "heelOver",
        "hemagglutinate",
        "hemolyze",
        "henpeck",
        "herniate",
        "heroWorship",
        "hesitate",
        "hibernate",
        "hierarchize",
        "higgle",
        "highlight",
        "hightail",
        "hingeOn",
        "hingeUpon",
        "hireOut",
        "hispanicize",
        "hitOff",
        "hoarsen",
        "hobble",
        "hobnob",
        "hogtie",
        "holdAgainst",
        "holdBack",
        "holdDown",
        "holdForth",
        "holdOff",
        "holdOn",
        "holdOut",
        "holdOver",
        "holdTo",
        "holdTogether",
        "holdUp",
        "holdWith",
        "hollow",
        "homogenize",
        "homologate",
        "homologize",
        "honour",
        "hoodwink",
        "hookUp",
        "hornswoggle",
        "horrify",
        "horsewhip",
        "hospitalize",
        "hotDog",
        "hotWire",
        "housebreak",
        "housesit",
        "housetrain",
        "humanise",
        "humanize",
        "humidify",
        "humiliate",
        "huntUp",
        "hurryUp",
        "hurtle",
        "hushUp",
        "hybridize",
        "hydrocrack",
        "hydrogenate",
        "hydrolyze",
        "hydroxylate",
        "hyperpolarize",
        "hyphenate",
        "hypnotize",
        "hyposensitize",
        "hypostatize",
        "hypothecate",
        "iceSkate",
        "idealise",
        "idealize",
        "identify",
        "idolize",
        "ignite",
        "ignore",
        "illTreat",
        "illegitimate",
        "illume",
        "illuminate",
        "illumine",
        "illustrate",
        "illuviate",
        "imagine",
        "imbibe",
        "imbrue",
        "imbrute",
        "imitate",
        "immaterialize",
        "immerge",
        "immerse",
        "immesh",
        "immigrate",
        "immobilise",
        "immobilize",
        "immolate",
        "immortalise",
        "immortalize",
        "immunize",
        "immure",
        "impair",
        "impale",
        "impanel",
        "impart",
        "impassion",
        "impaste",
        "impeach",
        "impearl",
        "impede",
        "impend",
        "imperil",
        "impersonalize",
        "impersonate",
        "implant",
        "implead",
        "implement",
        "implicate",
        "implode",
        "implore",
        "import",
        "impose",
        "impound",
        "impoverish",
        "imprecate",
        "impregnate",
        "impress",
        "imprint",
        "imprison",
        "improve",
        "improvise",
        "impugn",
        "impute",
        "inMigrate",
        "inactivate",
        "inaugurate",
        "inbreathe",
        "inbreed",
        "incandesce",
        "incapacitate",
        "incapsulate",
        "incarcerate",
        "incarnate",
        "incase",
        "incense",
        "incentivize",
        "incept",
        "incinerate",
        "incise",
        "incite",
        "inclasp",
        "incline",
        "inclose",
        "include",
        "incommode",
        "incorporate",
        "increase",
        "incriminate",
        "incrust",
        "incubate",
        "inculcate",
        "inculpate",
        "indemnify",
        "indent",
        "indentify",
        "indicate",
        "indict",
        "indispose",
        "indite",
        "individualise",
        "individualize",
        "individuate",
        "indoctrinate",
        "indorse",
        "induce",
        "induct",
        "indulge",
        "industrialise",
        "industrialize",
        "inebriate",
        "infatuate",
        "infect",
        "infest",
        "infiltrate",
        "inflame",
        "inflate",
        "inflect",
        "inflict",
        "influence",
        "inform",
        "infract",
        "infringe",
        "infuse",
        "ingest",
        "ingratiate",
        "ingurgitate",
        "inhabit",
        "inhale",
        "inhere",
        "inherit",
        "inhibit",
        "inhume",
        "initialize",
        "initiate",
        "inject",
        "injure",
        "inlace",
        "innervate",
        "innerve",
        "innovate",
        "inoculate",
        "inquire",
        "insalivate",
        "inscribe",
        "inseminate",
        "insert",
        "inshrine",
        "insinuate",
        "insist",
        "insnare",
        "insolate",
        "insoul",
        "inspect",
        "insphere",
        "inspire",
        "inspirit",
        "inspissate",
        "install",
        "instar",
        "instate",
        "instigate",
        "instil",
        "instill",
        "institute",
        "institutionalize",
        "instruct",
        "insufflate",
        "insulate",
        "insult",
        "integrate",
        "intellectualize",
        "intend",
        "intenerate",
        "intensify",
        "interact",
        "interbreed",
        "intercalate",
        "intercede",
        "intercept",
        "intercommunicate",
        "interconnect",
        "interdict",
        "interest",
        "interfere",
        "interiorize",
        "interject",
        "interlace",
        "interlock",
        "intermeddle",
        "intermingle",
        "intermit",
        "intermix",
        "internalize",
        "internationalise",
        "internationalize",
        "interpolate",
        "interpose",
        "interpret",
        "interrogate",
        "interrupt",
        "intersperse",
        "intertwine",
        "intervene",
        "interview",
        "interweave",
        "inthrall",
        "inthrone",
        "intimate",
        "intimidate",
        "intitule",
        "intonate",
        "intone",
        "intoxicate",
        "intreat",
        "intrench",
        "intrigue",
        "introduce",
        "introject",
        "intromit",
        "introspect",
        "intrude",
        "intrust",
        "intubate",
        "intuit",
        "intumesce",
        "intussuscept",
        "intwine",
        "intwist",
        "inundate",
        "invalidate",
        "inveigh",
        "inveigle",
        "invent",
        "invert",
        "invest",
        "investigate",
        "invigorate",
        "invite",
        "invocate",
        "invoice",
        "invoke",
        "involve",
        "inweave",
        "inwind",
        "inwrap",
        "inwreathe",
        "iodize",
        "ionize",
        "ironOut",
        "irradiate",
        "irrigate",
        "irritate",
        "irrupt",
        "islamize",
        "isochronize",
        "isolate",
        "italicize",
        "itemise",
        "itemize",
        "iterate",
        "itinerate",
        "jabber",
        "jamPack",
        "japanize",
        "jaywalk",
        "jellify",
        "jeopardize",
        "jerrybuild",
        "jobHop",
        "jobHunt",
        "jostle",
        "joypop",
        "jubilate",
        "juggle",
        "jumble",
        "juryRig",
        "justify",
        "juxtapose",
        "keelhaul",
        "keepBack",
        "kibitz",
        "kickOut",
        "kidnap",
        "kindle",
        "kneelDown",
        "knockDown",
        "knockOver",
        "knockTogether",
        "knockUp",
        "labialize",
        "lacerate",
        "lacquer",
        "lactate",
        "laicize",
        "lallygag",
        "lambaste",
        "lament",
        "laminate",
        "languish",
        "launch",
        "launder",
        "lavish",
        "leadAstray",
        "leakOut",
        "leaseOut",
        "leaveBehind",
        "legalise",
        "legalize",
        "legislate",
        "legitimate",
        "legitimatize",
        "legitimize",
        "lengthen",
        "letDown",
        "letOff",
        "letOut",
        "levant",
        "levelOff",
        "leverage",
        "levitate",
        "liaise",
        "liberalise",
        "liberalize",
        "liberate",
        "lieLow",
        "ligate",
        "limber",
        "lineUp",
        "linearize",
        "linger",
        "lionize",
        "liquate",
        "liquefy",
        "liquidate",
        "liquify",
        "listen",
        "literalize",
        "lithograph",
        "litigate",
        "litter",
        "lixiviate",
        "loathe",
        "lobotomize",
        "localize",
        "locate",
        "loiter",
        "lollop",
        "lollygag",
        "lookFor",
        "lookIn",
        "loosen",
        "louden",
        "lubricate",
        "lucubrate",
        "lumber",
        "luminesce",
        "lustrate",
        "luxate",
        "luxuriate",
        "lyophilize",
        "lysogenize",
        "macadamize",
        "macerate",
        "machicolate",
        "machineWash",
        "madden",
        "maffick",
        "magnetise",
        "magnetize",
        "magnify",
        "maintain",
        "makeHeadway",
        "makeOut",
        "makeProgress",
        "makeUp",
        "maladminister",
        "malinger",
        "maltreat",
        "manage",
        "mangle",
        "manhandle",
        "manhattanize",
        "manifest",
        "manipulate",
        "mantain",
        "manufacture",
        "manumit",
        "mapOut",
        "marbleize",
        "marginalize",
        "marinade",
        "marinate",
        "markOff",
        "market",
        "martyrize",
        "masculinize",
        "massProduce",
        "masticate",
        "materialize",
        "mathematize",
        "matriculate",
        "matter",
        "mature",
        "maunder",
        "maximise",
        "maximize",
        "measure",
        "measureAgainst",
        "measureOff",
        "measureOut",
        "measureUp",
        "mechanise",
        "mechanize",
        "meddle",
        "mediatize",
        "medicate",
        "meditate",
        "meetWith",
        "meltDown",
        "memorialize",
        "memorize",
        "menstruate",
        "mention",
        "mercerize",
        "mercurate",
        "mesmerise",
        "mesmerize",
        "metamorphose",
        "metastasize",
        "metathesize",
        "methinks",
        "methodize",
        "metrify",
        "microencapsulate",
        "microminiaturize",
        "micronize",
        "micturate",
        "migrate",
        "militarize",
        "militate",
        "miniaturize",
        "minify",
        "minimalize",
        "minimise",
        "minimize",
        "mirandize",
        "misaddress",
        "misallocate",
        "misally",
        "misapply",
        "misapprehend",
        "misappropriate",
        "misattribute",
        "misbecome",
        "misbelieve",
        "misbrand",
        "miscalculate",
        "miscall",
        "miscarry",
        "miscast",
        "mischaracterize",
        "misclassify",
        "misconceive",
        "misconstrue",
        "misdescribe",
        "misdiagnose",
        "misdial",
        "misdirect",
        "misdoubt",
        "miseducate",
        "misesteem",
        "misestimate",
        "misfile",
        "misfire",
        "misfuel",
        "misgovern",
        "misguide",
        "mishandle",
        "mishear",
        "mishit",
        "misidentify",
        "misinform",
        "misinterpret",
        "misknow",
        "mislabel",
        "mislay",
        "mislead",
        "mismanage",
        "mismatch",
        "mismate",
        "misname",
        "misorient",
        "misperceive",
        "misplace",
        "misprize",
        "misquote",
        "misread",
        "misremember",
        "misrepresent",
        "misspeak",
        "misspell",
        "misspend",
        "mistake",
        "mistime",
        "mistranslate",
        "mistreat",
        "mistrust",
        "misunderstand",
        "misuse",
        "misvalue",
        "misword",
        "miswrite",
        "mizzle",
        "mobilize",
        "modernize",
        "modify",
        "moisten",
        "moisturize",
        "molest",
        "mollify",
        "monetize",
        "mongrelize",
        "monish",
        "monitor",
        "monopolise",
        "monopolize",
        "monumentalize",
        "moralize",
        "mortgage",
        "mortify",
        "motivate",
        "motorize",
        "moulder",
        "mountUp",
        "mounts",
        "moveAway",
        "moveDown",
        "muckAbout",
        "muckAround",
        "muckIn",
        "muckOut",
        "muckUp",
        "muckrake",
        "muddle",
        "muffle",
        "multiply",
        "municipalize",
        "murder",
        "murmur",
        "musicalize",
        "muster",
        "mutagenize",
        "mutate",
        "mutilate",
        "mutter",
        "muzzle",
        "mystify",
        "mythicize",
        "nameDrop",
        "narcotize",
        "narrowcast",
        "nationalize",
        "naturalise",
        "naturalize",
        "navigate",
        "necessitate",
        "neglect",
        "negotiate",
        "neutralise",
        "nitrify",
        "nominate",
        "normalize",
        "notice",
        "notify",
        "nourish",
        "nullify",
        "number",
        "obelize",
        "object",
        "objectify",
        "oblige",
        "obliterate",
        "observe",
        "obsolesce",
        "obstruct",
        "obtain",
        "obtest",
        "obtrude",
        "obtund",
        "obturate",
        "obvert",
        "obviate",
        "occidentalize",
        "occupy",
        "officiate",
        "offload",
        "opalesce",
        "operate",
        "oppose",
        "oppress",
        "oppugn",
        "opsonize",
        "optimize",
        "orchestrate",
        "ordain",
        "organise",
        "organize",
        "orient",
        "orientate",
        "originate",
        "oscilate",
        "oscillate",
        "osmose",
        "ostracize",
        "outMigrate",
        "outProcess",
        "outbalance",
        "outbid",
        "outbreed",
        "outclass",
        "outdate",
        "outdistance",
        "outface",
        "outflank",
        "outfox",
        "outgeneral",
        "outgrow",
        "outguess",
        "outgun",
        "outlast",
        "outlay",
        "outlive",
        "outman",
        "outmaneuver",
        "outmatch",
        "outmode",
        "outmuscle",
        "outnumber",
        "outpace",
        "outperform",
        "outplace",
        "outplay",
        "outpoint",
        "outpoll",
        "output",
        "outrace",
        "outrange",
        "outrank",
        "outride",
        "outrun",
        "outsell",
        "outshine",
        "outsmart",
        "outsoar",
        "outsource",
        "outspeak",
        "outspend",
        "outstand",
        "outstare",
        "outstay",
        "outstretch",
        "outstrip",
        "outtalk",
        "outthink",
        "outvote",
        "outwait",
        "outwear",
        "outweigh",
        "outwit",
        "outwork",
        "overachieve",
        "overassess",
        "overawe",
        "overbear",
        "overcast",
        "overcharge",
        "overcome",
        "overcrop",
        "overdevelop",
        "overdo",
        "overdraw",
        "overeat",
        "overemphasize",
        "overestimate",
        "overexert",
        "overexpose",
        "overhang",
        "overhaul",
        "overhear",
        "overheat",
        "overjoy",
        "overlap",
        "overlay",
        "overlie",
        "overload",
        "overload",
        "overlook",
        "overmaster",
        "overmedicate",
        "overpay",
        "overpersuade",
        "overprint",
        "override",
        "overrun",
        "oversee",
        "oversell",
        "overshoot",
        "oversleep",
        "overtake",
        "overthrow",
        "overun",
        "overwhelm",
        "ovulate",
        "pacify",
        "packUp",
        "pageThrough",
        "palletize",
        "pamper",
        "panOff",
        "panOut",
        "parade",
        "paralyse",
        "partake",
        "participate",
        "particularise",
        "particularize",
        "passThrough",
        "passivate",
        "penetrate",
        "pension",
        "pensionOff",
        "perceive",
        "perforate",
        "perform",
        "perfuse",
        "perish",
        "permeate",
        "permit",
        "perorate",
        "perpetrate",
        "persist",
        "perspire",
        "persuade",
        "perturb",
        "pervade",
        "pickUp",
        "picture",
        "pierce",
        "pinpoint",
        "pipeDown",
        "placate",
        "plaster",
        "plastify",
        "playBack",
        "playTheMarket",
        "playback",
        "please",
        "pledge",
        "plough",
        "ploughBack",
        "ploughInto",
        "ploughOn",
        "ploughThrough",
        "ploughUp",
        "plunder",
        "plunge",
        "pointOut",
        "polish",
        "politicise",
        "politicize",
        "pollute",
        "polymerize",
        "populate",
        "portray",
        "position",
        "possess",
        "postdate",
        "postman",
        "postpone",
        "postulate",
        "pounce",
        "powder",
        "practise",
        "praise",
        "preSet",
        "preach",
        "precede",
        "precipitate",
        "preclude",
        "precook",
        "predestinate",
        "predict",
        "predominate",
        "prefer",
        "prefix",
        "prejudice",
        "prelude",
        "preoccupy",
        "prepare",
        "prescribe",
        "preserve",
        "preside",
        "pressurize",
        "presume",
        "pretend",
        "prevail",
        "prevaricate",
        "prevent",
        "privatize",
        "privide",
        "privilege",
        "probate",
        "proceed",
        "process",
        "proclaim",
        "procrastinate",
        "procreate",
        "produce",
        "profess",
        "profile",
        "program",
        "programme",
        "progress",
        "prohibit",
        "project",
        "prolong",
        "promise",
        "promote",
        "pronounce",
        "proofread",
        "propagate",
        "propel",
        "propose",
        "prorate",
        "prorogue",
        "prosecute",
        "protect",
        "protest",
        "provide",
        "provideFor",
        "provoke",
        "publish",
        "pullOut",
        "pulverize",
        "punish",
        "purchase",
        "purify",
        "pursue",
        "pushOff",
        "pushback",
        "putAbout",
        "putAcross",
        "putAside",
        "putAway",
        "putBack",
        "putDown",
        "putForth",
        "putForward",
        "putIntoOrder",
        "putOff",
        "putOnto",
        "putOut",
        "putOver",
        "putThrough",
        "putTogether",
        "qualify",
        "quantify",
        "quench",
        "question",
        "raddle",
        "radicalize",
        "radiobroadcast",
        "rail     ",
        "ramp     ",
        "randomize",
        "ransack",
        "rarify",
        "ratify",
        "ratiocinate",
        "rationalise",
        "rationalize",
        "rattle",
        "ravish",
        "reCede",
        "reCollect",
        "reCover",
        "reDirect",
        "reEducate",
        "reElect",
        "reEnact",
        "reEnforce",
        "reExamine",
        "reFund",
        "reLease",
        "reSign",
        "reSort",
        "reactivate",
        "reaffirm",
        "realign",
        "realize",
        "reanimate",
        "reapportion",
        "reappraise",
        "reargue",
        "rearrange",
        "reassign",
        "reassure",
        "rebind",
        "reboot",
        "rebound",
        "rebuild",
        "recalculate",
        "recall",
        "recapitalize",
        "recapture",
        "recast",
        "recede",
        "receive",
        "recertify",
        "recharge",
        "reciprocate",
        "reckon",
        "reclaim",
        "reclaim",
        "recline",
        "recognize",
        "recollect",
        "recommend",
        "recommit",
        "recompose",
        "reconcile",
        "recondition",
        "reconfirm",
        "reconnect",
        "reconsider",
        "reconstitute",
        "reconstruct",
        "reconvert",
        "reconvey",
        "record",
        "recount",
        "recover",
        "recreate",
        "recrudesce",
        "recruit",
        "rectify",
        "recuperate",
        "recurve",
        "recuse",
        "recycle",
        "redBait",
        "redPencil",
        "redact",
        "redden",
        "redeem",
        "redeliver",
        "redeploy",
        "redesign",
        "redirect",
        "redistribute",
        "redistrict",
        "redouble",
        "redound",
        "redraw",
        "reduce",
        "reelBack",
        "reelOff",
        "reestablish",
        "refect",
        "referTo",
        "refinance",
        "refine",
        "refinish",
        "reflag",
        "reflate",
        "reflect",
        "reflectorize",
        "reforest",
        "reform",
        "refract",
        "refresh",
        "refreshen",
        "refrigerate",
        "refund",
        "refurbish",
        "refuse",
        "refute",
        "regain",
        "regard",
        "regelate",
        "regenerate",
        "regionalize",
        "register",
        "regorge",
        "regret",
        "regularize",
        "regulate",
        "rehabilitate",
        "rehear",
        "rehouse",
        "rehydrate",
        "reimburse",
        "reimport",
        "reincarnate",
        "reinforce",
        "reinstall",
        "reinstate",
        "reinsure",
        "reintegrate",
        "reinterpret",
        "reinvent",
        "reinvest",
        "reinvigorate",
        "reiterate",
        "reject",
        "rejigger",
        "rejoice",
        "rejoin",
        "rejuvenate",
        "rekindle",
        "relapse",
        "relate",
        "relaunch",
        "release",
        "relegate",
        "relieve",
        "reline",
        "relinquish",
        "relish",
        "reload",
        "reluct",
        "relume",
        "remain",
        "remake",
        "remand",
        "remember",
        "remilitarize",
        "remind",
        "reminisce",
        "remint",
        "remise",
        "remodel",
        "remonetize",
        "remove",
        "remunerate",
        "rename",
        "render",
        "renegotiate",
        "renominate",
        "renormalize",
        "renounce",
        "renovate",
        "renumber",
        "reopen",
        "reorganize",
        "repackage",
        "repatriate",
        "repeal",
        "repeat",
        "repent",
        "rephrase",
        "repine",
        "replace",
        "replay",
        "replicate",
        "repolarize",
        "report",
        "repose",
        "reposit",
        "repossess",
        "reprehend",
        "represent",
        "reprint",
        "reproach",
        "reprocess",
        "reproduce",
        "reprogram",
        "reprove",
        "republicanize",
        "republish",
        "repudiate",
        "request",
        "require",
        "requite",
        "reradiate",
        "rerelease",
        "reschedule",
        "rescind",
        "research",
        "reseat",
        "resect",
        "resell",
        "resemble",
        "resent",
        "reserve",
        "reshape",
        "reshuffle",
        "reside",
        "resile",
        "resinate",
        "resole",
        "resolve",
        "resonate",
        "respect",
        "respell",
        "respond",
        "restOn",
        "restUpon",
        "restWith",
        "restock",
        "restore",
        "restrain",
        "restrict",
        "restructure",
        "result",
        "resume",
        "resupply",
        "resurge",
        "resurrect",
        "retail",
        "retain",
        "retake",
        "retarget",
        "retell",
        "rethink",
        "retire",
        "retouch",
        "retrace",
        "retract",
        "retrain",
        "retread",
        "retrieve",
        "retrogress",
        "return",
        "reunify",
        "reunite",
        "revalidate",
        "revaluate",
        "revalue",
        "reveal",
        "revere",
        "reverse",
        "revest",
        "review",
        "revise",
        "revitalize",
        "revivify",
        "revoke",
        "revolutionize",
        "rewaken",
        "rewind",
        "reword",
        "rewound",
        "rewrite",
        "rezone",
        "richen",
        "rigidify",
        "robotize",
        "roentgenize",
        "roister",
        "rollerSkate",
        "romanize",
        "roquet",
        "rotate",
        "rototill",
        "roughHew",
        "roughIn",
        "roughOut",
        "roughUp",
        "roughen",
        "roundOff",
        "routinize",
        "rubberStamp",
        "rubberize",
        "rubricate",
        "ruffle",
        "ruleOut",
        "runInto",
        "runOff",
        "runOff",
        "ruralize",
        "russianize",
        "sabotage",
        "saccharify",
        "sacrifice",
        "sadden",
        "salinize",
        "salute",
        "sample",
        "sample",
        "sanctify",
        "sandCast",
        "sandblast",
        "sanitise",
        "sanitize",
        "satirize",
        "satisfy",
        "saturate",
        "savour",
        "scabble",
        "scaleDown",
        "scandalize",
        "scarify",
        "scatter",
        "schedule",
        "schematize",
        "scorify",
        "scramble",
        "scrape",
        "scream",
        "screen",
        "screwAround",
        "screwUp",
        "scribble",
        "scroll",
        "scrooch",
        "scrutinise",
        "scrutinize",
        "scupper",
        "scutch",
        "scutter",
        "search",
        "search",
        "secede",
        "secern",
        "seclude",
        "secrete",
        "sectionalize",
        "secularize",
        "securitize",
        "sedate",
        "seduce",
        "seethe",
        "select",
        "selfActualize",
        "selfAdminister",
        "sensationalize",
        "sensualize",
        "separate",
        "sequestrate",
        "serialize",
        "setAgainst",
        "setApart",
        "setAside",
        "setBack",
        "setDown",
        "setForth",
        "setOff",
        "setOut",
        "settle",
        "sexualize",
        "shadowbox",
        "shakeOut",
        "shanghai",
        "sharpen",
        "shatter",
        "sheathe",
        "sheave",
        "shelter",
        "shield",
        "shimmer",
        "shinny",
        "shiver",
        "shortList",
        "shortchange",
        "shorten",
        "shower",
        "shrink",
        "shrive",
        "shrivel",
        "shutDown",
        "shutOff",
        "sibilate",
        "sicken",
        "sideslip",
        "sidestep",
        "sightsee",
        "signalize",
        "silkScreen",
        "silverPlate",
        "simplify",
        "simulate",
        "single",
        "singularize",
        "sinicize",
        "sinify",
        "skedaddle",
        "skeletonize",
        "skinDive",
        "skinPop",
        "skinnyDip",
        "skyjack",
        "slacken",
        "slenderize",
        "slicken",
        "sloganize",
        "slowDown",
        "smolder",
        "smooth",
        "smoothen",
        "smoulder",
        "snuggle",
        "sodomize",
        "softLand",
        "softPedal",
        "softSoap",
        "soften",
        "solemnize",
        "solicit",
        "soliloquize",
        "solubilize",
        "somnambulate",
        "soothsay",
        "soundOff",
        "soundOut",
        "sovietize",
        "sparkle",
        "sparkplug",
        "spearfish",
        "specify",
        "spectate",
        "speculate",
        "speechify",
        "spiritualize",
        "splash",
        "sponge",
        "spoonFeed",
        "sporulate",
        "spotCheck",
        "spotlight",
        "spread",
        "spring",
        "springe",
        "sprinkle",
        "spyOut",
        "squander",
        "square",
        "squeak",
        "squeal",
        "squeeze",
        "squeeze",
        "squinch",
        "stageManage",
        "stagger",
        "stagnate",
        "stallFeed",
        "stampOut",
        "stanch",
        "standUp",
        "standardize",
        "staple",
        "stargaze",
        "staunch",
        "steady",
        "steepen",
        "sterilize",
        "stickUp",
        "stickle",
        "stiffen",
        "stifle",
        "stigmatize",
        "stimulate",
        "stipulate",
        "stitch",
        "stitchUp",
        "stopper",
        "stormInto",
        "stouten",
        "straddle",
        "straighten",
        "straightenUp",
        "strain",
        "straiten",
        "strangle",
        "strapHang",
        "streak",
        "streamline",
        "strengthen",
        "stress",
        "stretch",
        "stride",
        "strike",
        "strikeBack",
        "strikeDown",
        "strikeOff",
        "strikeOut",
        "strikeUp",
        "string",
        "stripSearch",
        "strive",
        "structuralize",
        "structure",
        "stultify",
        "stumble",
        "stupefy",
        "stutter",
        "stylize",
        "subdue",
        "suberize",
        "subinfeudate",
        "subirrigate",
        "subject",
        "subjoin",
        "subjugate",
        "sublate",
        "sublease",
        "sublet",
        "submerse",
        "subminiaturize",
        "submit",
        "subordinate",
        "suborn",
        "subpoena",
        "subrogate",
        "subscribe",
        "subserve",
        "subside",
        "subsidise",
        "subsidize",
        "subsist",
        "subspecialize",
        "substantiate",
        "subsume",
        "subtend",
        "subtract",
        "suburbanize",
        "subvert",
        "subvocalize",
        "succeed",
        "succumb",
        "suckle",
        "suffer",
        "suffuse",
        "suggest",
        "sulfurate",
        "sulfurize",
        "summarize",
        "summon",
        "sunbathe",
        "superabound",
        "superannuate",
        "supercharge",
        "supererogate",
        "superfetate",
        "superimpose",
        "superinduce",
        "superinfect",
        "superintend",
        "superpose",
        "supersaturate",
        "superscribe",
        "supersede",
        "supervene",
        "supervise",
        "supplant",
        "supplicate",
        "supply",
        "support",
        "suppose",
        "suppress",
        "suppurate",
        "surmount",
        "surpass",
        "surprint",
        "surrender",
        "surround",
        "surveille",
        "survive",
        "suspect",
        "suspend",
        "suspire",
        "sustain",
        "swaddle",
        "swallow",
        "sweeten",
        "swelter",
        "swerve",
        "swindle",
        "swinge",
        "switch",
        "switch",
        "switchOff",
        "switchOn",
        "switchOver",
        "syllabify",
        "syllabize",
        "symmetrize",
        "sympathise",
        "sympathize",
        "symptomatize",
        "symptomize",
        "synchronise",
        "synchronize",
        "syncopate",
        "synonymize",
        "synopsize",
        "sypher",
        "systematize",
        "systemize",
        "tableHop",
        "tabularize",
        "tabulate",
        "tackle",
        "takeUpPosition",
        "tamper",
        "tangle",
        "tantalize",
        "tapDance",
        "tapeRecord",
        "tartarize",
        "tauten",
        "tautologize",
        "teamTeach",
        "tearGas",
        "teethe",
        "telecommute",
        "telegraph",
        "telephone",
        "televise",
        "temper",
        "temporize",
        "tender",
        "tenderize",
        "tergiversate",
        "terminate",
        "terrify",
        "territorialize",
        "terrorize",
        "tessellate",
        "testDrive",
        "testify",
        "tetanize",
        "teutonize",
        "texturize",
        "theatricalize",
        "thermoregulate",
        "thicken",
        "thieve",
        "thread",
        "threaten",
        "thresh",
        "thrive",
        "throng",
        "throttle",
        "thrust",
        "thunder",
        "tighten",
        "tinPlate",
        "titivate",
        "titrate",
        "toHopOut",
        "toHope",
        "toStay",
        "toTalk",
        "toWant",
        "tolerate",
        "topDress",
        "topOff",
        "topOut",
        "torment",
        "torture",
        "totalize",
        "totter",
        "touchType",
        "toughen",
        "tradeDown",
        "tradeIn",
        "tradeOff",
        "tradeOn",
        "tradeUp",
        "tradeUpon",
        "tradizionalize",
        "traduce",
        "traipse",
        "traject",
        "tranquillize",
        "transcode",
        "transcribe",
        "transect",
        "transfer",
        "transfigure",
        "transfix",
        "transform",
        "transfuse",
        "transgress",
        "tranship",
        "transistorize",
        "transit",
        "translate",
        "transliterate",
        "translocate",
        "transmigrate",
        "transmit",
        "transmogrify",
        "transplant",
        "transport",
        "transship",
        "transubstantiate",
        "transude",
        "transvalue",
        "traumatize",
        "travel",
        "traverse",
        "tremble",
        "trickOrTreat",
        "trickle",
        "trisect",
        "triumph",
        "trivialize",
        "trouble",
        "trounce",
        "truncate",
        "tubThump",
        "tuckPoint",
        "tucker",
        "tumble",
        "tumbleDry",
        "tumefy",
        "turnAway",
        "turnOff",
        "turnOn",
        "tutTut",
        "tweeze",
        "twinkle",
        "twoTime",
        "typewrite",
        "typify",
        "tyrannize",
        "uglify",
        "ululate",
        "unbend",
        "unbind",
        "unblock",
        "unbolt",
        "unbrace",
        "unbridle",
        "unbuild",
        "unburden",
        "unchain",
        "unchurch",
        "uncloak",
        "unclog",
        "unclothe",
        "uncoil",
        "unconfigure",
        "uncork",
        "uncover",
        "uncross",
        "undeceive",
        "undelete",
        "underachieve",
        "underbuy",
        "undercapitalise",
        "undercapitalize",
        "undercool",
        "underdo",
        "underemphasize",
        "underestimate",
        "underexpose",
        "underfeed",
        "underfund",
        "undergird",
        "undergo",
        "underinsure",
        "underlay",
        "underlet",
        "underlie",
        "underline",
        "undermine",
        "undermodulate",
        "undernourish",
        "underpay",
        "underpin",
        "underprice",
        "underprop",
        "underquote",
        "underrate",
        "underreport",
        "underrun",
        "underscore",
        "undersell",
        "undersign",
        "understand",
        "understate",
        "undertake",
        "undertrump",
        "undervalue",
        "underwhelm",
        "underwrite",
        "undraw",
        "unearth",
        "unfetter",
        "unfrock",
        "unfurl",
        "unglue",
        "unguarde",
        "unhallow",
        "unhand",
        "unharness",
        "unhinge",
        "unhitch",
        "unhook",
        "unhorse",
        "unitize",
        "universalize",
        "unjoint",
        "unkennel",
        "unknit",
        "unlace",
        "unlade",
        "unlash",
        "unlead",
        "unlearn",
        "unleash",
        "unlive",
        "unload",
        "unlock",
        "unloose",
        "unloosen",
        "unmake",
        "unmask",
        "unmold",
        "unmount",
        "unmuzzle",
        "unnerve",
        "unpack",
        "unpeople",
        "unpick",
        "unpile",
        "unplug",
        "unprovide",
        "unravel",
        "unreel",
        "unriddle",
        "unroof",
        "unroot",
        "unround",
        "unscramble",
        "unscrew",
        "unseal",
        "unseam",
        "unseat",
        "unsell",
        "unshackle",
        "unsheath",
        "unshell",
        "unsling",
        "unsnap",
        "unsnarl",
        "unspeak",
        "unsphere",
        "unsteel",
        "unstep",
        "unstick",
        "unstop",
        "unstrap",
        "unstring",
        "unswathe",
        "unswear",
        "untangle",
        "unteach",
        "unthink",
        "unthread",
        "unthrone",
        "untread",
        "unveil",
        "unvoice",
        "unwind",
        "unwish",
        "unwrap",
        "upbraid",
        "upbuild",
        "upchuck",
        "update",
        "upgrade",
        "uphold",
        "upholster",
        "uplift",
        "upload",
        "upraise",
        "uprise",
        "uproot",
        "upshift",
        "upspring",
        "upwell",
        "urbanize",
        "urinate",
        "utilise",
        "utilize",
        "vaccinate",
        "vacillate",
        "validate",
        "valorize",
        "valuate",
        "vamoose",
        "vandalize",
        "vanish",
        "vanquish",
        "vaporise",
        "vaporize",
        "vaporize",
        "variegate",
        "varnish",
        "vascularize",
        "vasectomize",
        "vegetate",
        "velarize",
        "venerate",
        "ventilate",
        "ventriloquize",
        "verbify",
        "verify",
        "vernacularize",
        "vesicate",
        "vibrate",
        "victimize",
        "victorianize",
        "vilify",
        "vilipend",
        "vindicate",
        "violate",
        "visualise",
        "visualize",
        "vitalize",
        "vitiate",
        "vivify",
        "vocalise",
        "vociferate",
        "volatilize",
        "volcanize",
        "vorlesen",
        "vouchsafe",
        "vowelize",
        "voyage",
        "vulcanize",
        "vulgarize",
        "wander",
        "warmUp",
        "warrant",
        "waterCool",
        "waterJacket",
        "waterSki",
        "waylay",
        "weaken",
        "weatherStrip",
        "weatherize",
        "welcome",
        "westernize",
        "wetNurse",
        "wheeze",
        "whistle",
        "whistleStop",
        "whiten",
        "windowShop",
        "winkle",
        "winter",
        "winterfeed",
        "winterize",
        "wiredraw",
        "withdraw",
        "withold",
        "withstand",
        "witness",
        "wobble",
        "wonder",
        "woolGather",
        "workOut",
        "worsen",
        "worship",
        "wrangle",
        "wreathe",
        "wriggle",
        "writeOff",
        "xIrradiate",
        "zeroRate",
        "zoomIn",
    };

}

