#!/usr/bin/python

import sys, re

constant_map = {
    1024: 'GL_FRONT_LEFT',
    1025: 'GL_FRONT_RIGHT',
    1026: 'GL_BACK_LEFT',
    1027: 'GL_BACK_RIGHT',
    1028: 'GL_FRONT',
    1029: 'GL_BACK',
    1030: 'GL_LEFT',
    1031: 'GL_RIGHT',
    1032: 'GL_FRONT_AND_BACK',
    1033: 'GL_AUX0',
    1034: 'GL_AUX1',
    1035: 'GL_AUX2',
    1036: 'GL_AUX3',
    1280: 'GL_INVALID_ENUM',
    1281: 'GL_INVALID_VALUE',
    1282: 'GL_INVALID_OPERATION',
    1283: 'GL_STACK_OVERFLOW',
    1284: 'GL_STACK_UNDERFLOW',
    1285: 'GL_OUT_OF_MEMORY',
    1286: 'GL_INVALID_FRAMEBUFFER_OPERATION_EXT',
    1536: 'GL_2D',
    1537: 'GL_3D',
    1538: 'GL_3D_COLOR',
    1539: 'GL_3D_COLOR_TEXTURE',
    1540: 'GL_4D_COLOR_TEXTURE',
    1792: 'GL_PASS_THROUGH_TOKEN',
    1793: 'GL_POINT_TOKEN',
    1794: 'GL_LINE_TOKEN',
    1795: 'GL_POLYGON_TOKEN',
    1796: 'GL_BITMAP_TOKEN',
    1797: 'GL_DRAW_PIXEL_TOKEN',
    1798: 'GL_COPY_PIXEL_TOKEN',
    1799: 'GL_LINE_RESET_TOKEN',
    2048: 'GL_EXP',
    2049: 'GL_EXP2',
    2304: 'GL_CW',
    2305: 'GL_CCW',
    2560: 'GL_COEFF',
    2561: 'GL_ORDER',
    2562: 'GL_DOMAIN',
    2816: 'GL_CURRENT_COLOR',
    2817: 'GL_CURRENT_INDEX',
    2818: 'GL_CURRENT_NORMAL',
    2819: 'GL_CURRENT_TEXTURE_COORDS',
    2820: 'GL_CURRENT_RASTER_COLOR',
    2821: 'GL_CURRENT_RASTER_INDEX',
    2822: 'GL_CURRENT_RASTER_TEXTURE_COORDS',
    2823: 'GL_CURRENT_RASTER_POSITION',
    2824: 'GL_CURRENT_RASTER_POSITION_VALID',
    2825: 'GL_CURRENT_RASTER_DISTANCE',
    2832: 'GL_POINT_SMOOTH',
    2833: 'GL_POINT_SIZE',
    2834: 'GL_SMOOTH_POINT_SIZE_RANGE',
    2835: 'GL_SMOOTH_POINT_SIZE_GRANULARITY',
    2848: 'GL_LINE_SMOOTH',
    2849: 'GL_LINE_WIDTH',
    2850: 'GL_SMOOTH_LINE_WIDTH_RANGE',
    2851: 'GL_SMOOTH_LINE_WIDTH_GRANULARITY',
    2852: 'GL_LINE_STIPPLE',
    2853: 'GL_LINE_STIPPLE_PATTERN',
    2854: 'GL_LINE_STIPPLE_REPEAT',
    2864: 'GL_LIST_MODE',
    2865: 'GL_MAX_LIST_NESTING',
    2866: 'GL_LIST_BASE',
    2867: 'GL_LIST_INDEX',
    2880: 'GL_POLYGON_MODE',
    2881: 'GL_POLYGON_SMOOTH',
    2882: 'GL_POLYGON_STIPPLE',
    2883: 'GL_EDGE_FLAG',
    2884: 'GL_CULL_FACE',
    2885: 'GL_CULL_FACE_MODE',
    2886: 'GL_FRONT_FACE',
    2896: 'GL_LIGHTING',
    2897: 'GL_LIGHT_MODEL_LOCAL_VIEWER',
    2898: 'GL_LIGHT_MODEL_TWO_SIDE',
    2899: 'GL_LIGHT_MODEL_AMBIENT',
    2900: 'GL_SHADE_MODEL',
    2901: 'GL_COLOR_MATERIAL_FACE',
    2902: 'GL_COLOR_MATERIAL_PARAMETER',
    2903: 'GL_COLOR_MATERIAL',
    2912: 'GL_FOG',
    2913: 'GL_FOG_INDEX',
    2914: 'GL_FOG_DENSITY',
    2915: 'GL_FOG_START',
    2916: 'GL_FOG_END',
    2917: 'GL_FOG_MODE',
    2918: 'GL_FOG_COLOR',
    2928: 'GL_DEPTH_RANGE',
    2929: 'GL_DEPTH_TEST',
    2930: 'GL_DEPTH_WRITEMASK',
    2931: 'GL_DEPTH_CLEAR_VALUE',
    2932: 'GL_DEPTH_FUNC',
    2944: 'GL_ACCUM_CLEAR_VALUE',
    2960: 'GL_STENCIL_TEST',
    2961: 'GL_STENCIL_CLEAR_VALUE',
    2962: 'GL_STENCIL_FUNC',
    2963: 'GL_STENCIL_VALUE_MASK',
    2964: 'GL_STENCIL_FAIL',
    2965: 'GL_STENCIL_PASS_DEPTH_FAIL',
    2966: 'GL_STENCIL_PASS_DEPTH_PASS',
    2967: 'GL_STENCIL_REF',
    2968: 'GL_STENCIL_WRITEMASK',
    2976: 'GL_MATRIX_MODE',
    2977: 'GL_NORMALIZE',
    2978: 'GL_VIEWPORT',
    2979: 'GL_MODELVIEW_STACK_DEPTH',
    2980: 'GL_PROJECTION_STACK_DEPTH',
    2981: 'GL_TEXTURE_STACK_DEPTH',
    2982: 'GL_MODELVIEW_MATRIX',
    2983: 'GL_PROJECTION_MATRIX',
    2984: 'GL_TEXTURE_MATRIX',
    2992: 'GL_ATTRIB_STACK_DEPTH',
    2993: 'GL_CLIENT_ATTRIB_STACK_DEPTH',
    3008: 'GL_ALPHA_TEST',
    3009: 'GL_ALPHA_TEST_FUNC',
    3010: 'GL_ALPHA_TEST_REF',
    3024: 'GL_DITHER',
    3040: 'GL_BLEND_DST',
    3041: 'GL_BLEND_SRC',
    3042: 'GL_BLEND',
    3056: 'GL_LOGIC_OP_MODE',
    3057: 'GL_INDEX_LOGIC_OP',
    3058: 'GL_COLOR_LOGIC_OP',
    3072: 'GL_AUX_BUFFERS',
    3073: 'GL_DRAW_BUFFER',
    3074: 'GL_READ_BUFFER',
    3088: 'GL_SCISSOR_BOX',
    3089: 'GL_SCISSOR_TEST',
    3104: 'GL_INDEX_CLEAR_VALUE',
    3105: 'GL_INDEX_WRITEMASK',
    3106: 'GL_COLOR_CLEAR_VALUE',
    3107: 'GL_COLOR_WRITEMASK',
    3120: 'GL_INDEX_MODE',
    3121: 'GL_RGBA_MODE',
    3122: 'GL_DOUBLEBUFFER',
    3123: 'GL_STEREO',
    3136: 'GL_RENDER_MODE',
    3152: 'GL_PERSPECTIVE_CORRECTION_HINT',
    3153: 'GL_POINT_SMOOTH_HINT',
    3154: 'GL_LINE_SMOOTH_HINT',
    3155: 'GL_POLYGON_SMOOTH_HINT',
    3156: 'GL_FOG_HINT',
    3168: 'GL_TEXTURE_GEN_S',
    3169: 'GL_TEXTURE_GEN_T',
    3170: 'GL_TEXTURE_GEN_R',
    3171: 'GL_TEXTURE_GEN_Q',
    3184: 'GL_PIXEL_MAP_I_TO_I',
    3185: 'GL_PIXEL_MAP_S_TO_S',
    3186: 'GL_PIXEL_MAP_I_TO_R',
    3187: 'GL_PIXEL_MAP_I_TO_G',
    3188: 'GL_PIXEL_MAP_I_TO_B',
    3189: 'GL_PIXEL_MAP_I_TO_A',
    3190: 'GL_PIXEL_MAP_R_TO_R',
    3191: 'GL_PIXEL_MAP_G_TO_G',
    3192: 'GL_PIXEL_MAP_B_TO_B',
    3193: 'GL_PIXEL_MAP_A_TO_A',
    3248: 'GL_PIXEL_MAP_I_TO_I_SIZE',
    3249: 'GL_PIXEL_MAP_S_TO_S_SIZE',
    3250: 'GL_PIXEL_MAP_I_TO_R_SIZE',
    3251: 'GL_PIXEL_MAP_I_TO_G_SIZE',
    3252: 'GL_PIXEL_MAP_I_TO_B_SIZE',
    3253: 'GL_PIXEL_MAP_I_TO_A_SIZE',
    3254: 'GL_PIXEL_MAP_R_TO_R_SIZE',
    3255: 'GL_PIXEL_MAP_G_TO_G_SIZE',
    3256: 'GL_PIXEL_MAP_B_TO_B_SIZE',
    3257: 'GL_PIXEL_MAP_A_TO_A_SIZE',
    3312: 'GL_UNPACK_SWAP_BYTES',
    3313: 'GL_UNPACK_LSB_FIRST',
    3314: 'GL_UNPACK_ROW_LENGTH',
    3315: 'GL_UNPACK_SKIP_ROWS',
    3316: 'GL_UNPACK_SKIP_PIXELS',
    3317: 'GL_UNPACK_ALIGNMENT',
    3328: 'GL_PACK_SWAP_BYTES',
    3329: 'GL_PACK_LSB_FIRST',
    3330: 'GL_PACK_ROW_LENGTH',
    3331: 'GL_PACK_SKIP_ROWS',
    3332: 'GL_PACK_SKIP_PIXELS',
    3333: 'GL_PACK_ALIGNMENT',
    3344: 'GL_MAP_COLOR',
    3345: 'GL_MAP_STENCIL',
    3346: 'GL_INDEX_SHIFT',
    3347: 'GL_INDEX_OFFSET',
    3348: 'GL_RED_SCALE',
    3349: 'GL_RED_BIAS',
    3350: 'GL_ZOOM_X',
    3351: 'GL_ZOOM_Y',
    3352: 'GL_GREEN_SCALE',
    3353: 'GL_GREEN_BIAS',
    3354: 'GL_BLUE_SCALE',
    3355: 'GL_BLUE_BIAS',
    3356: 'GL_ALPHA_SCALE',
    3357: 'GL_ALPHA_BIAS',
    3358: 'GL_DEPTH_SCALE',
    3359: 'GL_DEPTH_BIAS',
    3376: 'GL_MAX_EVAL_ORDER',
    3377: 'GL_MAX_LIGHTS',
    3378: 'GL_MAX_CLIP_PLANES',
    3379: 'GL_MAX_TEXTURE_SIZE',
    3380: 'GL_MAX_PIXEL_MAP_TABLE',
    3381: 'GL_MAX_ATTRIB_STACK_DEPTH',
    3382: 'GL_MAX_MODELVIEW_STACK_DEPTH',
    3383: 'GL_MAX_NAME_STACK_DEPTH',
    3384: 'GL_MAX_PROJECTION_STACK_DEPTH',
    3385: 'GL_MAX_TEXTURE_STACK_DEPTH',
    3386: 'GL_MAX_VIEWPORT_DIMS',
    3387: 'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH',
    3440: 'GL_NAME_STACK_DEPTH',
    3456: 'GL_AUTO_NORMAL',
    3472: 'GL_MAP1_COLOR_4',
    3473: 'GL_MAP1_INDEX',
    3474: 'GL_MAP1_NORMAL',
    3475: 'GL_MAP1_TEXTURE_COORD_1',
    3476: 'GL_MAP1_TEXTURE_COORD_2',
    3477: 'GL_MAP1_TEXTURE_COORD_3',
    3478: 'GL_MAP1_TEXTURE_COORD_4',
    3479: 'GL_MAP1_VERTEX_3',
    3480: 'GL_MAP1_VERTEX_4',
    3504: 'GL_MAP2_COLOR_4',
    3505: 'GL_MAP2_INDEX',
    3506: 'GL_MAP2_NORMAL',
    3507: 'GL_MAP2_TEXTURE_COORD_1',
    3508: 'GL_MAP2_TEXTURE_COORD_2',
    3509: 'GL_MAP2_TEXTURE_COORD_3',
    3510: 'GL_MAP2_TEXTURE_COORD_4',
    3511: 'GL_MAP2_VERTEX_3',
    3512: 'GL_MAP2_VERTEX_4',
    3536: 'GL_MAP1_GRID_DOMAIN',
    3537: 'GL_MAP1_GRID_SEGMENTS',
    3538: 'GL_MAP2_GRID_DOMAIN',
    3539: 'GL_MAP2_GRID_SEGMENTS',
    3552: 'GL_TEXTURE_1D',
    3553: 'GL_TEXTURE_2D',
    3568: 'GL_FEEDBACK_BUFFER_POINTER',
    3569: 'GL_FEEDBACK_BUFFER_SIZE',
    3570: 'GL_FEEDBACK_BUFFER_TYPE',
    3571: 'GL_SELECTION_BUFFER_POINTER',
    3572: 'GL_SELECTION_BUFFER_SIZE',
    4096: 'GL_TEXTURE_WIDTH',
    4097: 'GL_TEXTURE_HEIGHT',
    4099: 'GL_TEXTURE_INTERNAL_FORMAT',
    4100: 'GL_TEXTURE_BORDER_COLOR',
    4101: 'GL_TEXTURE_BORDER',
    4352: 'GL_DONT_CARE',
    4353: 'GL_FASTEST',
    4354: 'GL_NICEST',
    4608: 'GL_AMBIENT',
    4609: 'GL_DIFFUSE',
    4610: 'GL_SPECULAR',
    4611: 'GL_POSITION',
    4612: 'GL_SPOT_DIRECTION',
    4613: 'GL_SPOT_EXPONENT',
    4614: 'GL_SPOT_CUTOFF',
    4615: 'GL_CONSTANT_ATTENUATION',
    4616: 'GL_LINEAR_ATTENUATION',
    4617: 'GL_QUADRATIC_ATTENUATION',
    4864: 'GL_COMPILE',
    4865: 'GL_COMPILE_AND_EXECUTE',
    5120: 'GL_BYTE',
    5121: 'GL_UNSIGNED_BYTE',
    5122: 'GL_SHORT',
    5123: 'GL_UNSIGNED_SHORT',
    5124: 'GL_INT',
    5125: 'GL_UNSIGNED_INT',
    5126: 'GL_FLOAT',
    5127: 'GL_2_BYTES',
    5128: 'GL_3_BYTES',
    5129: 'GL_4_BYTES',
    5130: 'GL_DOUBLE_EXT',
    5131: 'GL_HALF_FLOAT_ARB',
    5376: 'GL_CLEAR',
    5377: 'GL_AND',
    5378: 'GL_AND_REVERSE',
    5379: 'GL_COPY',
    5380: 'GL_AND_INVERTED',
    5381: 'GL_NOOP',
    5382: 'GL_XOR',
    5383: 'GL_OR',
    5384: 'GL_NOR',
    5385: 'GL_EQUIV',
    5386: 'GL_INVERT',
    5387: 'GL_OR_REVERSE',
    5388: 'GL_COPY_INVERTED',
    5389: 'GL_OR_INVERTED',
    5390: 'GL_NAND',
    5391: 'GL_SET',
    5632: 'GL_EMISSION',
    5633: 'GL_SHININESS',
    5634: 'GL_AMBIENT_AND_DIFFUSE',
    5635: 'GL_COLOR_INDEXES',
    5888: 'GL_MODELVIEW0_ARB',
    5889: 'GL_PROJECTION',
    5890: 'GL_TEXTURE',
    6144: 'GL_COLOR',
    6145: 'GL_DEPTH',
    6146: 'GL_STENCIL',
    6400: 'GL_COLOR_INDEX',
    6401: 'GL_STENCIL_INDEX',
    6402: 'GL_DEPTH_COMPONENT',
    6403: 'GL_RED',
    6404: 'GL_GREEN',
    6405: 'GL_BLUE',
    6406: 'GL_ALPHA',
    6407: 'GL_RGB',
    6408: 'GL_RGBA',
    6409: 'GL_LUMINANCE',
    6410: 'GL_LUMINANCE_ALPHA',
    6656: 'GL_BITMAP',
    6912: 'GL_POINT',
    6913: 'GL_LINE',
    6914: 'GL_FILL',
    7168: 'GL_RENDER',
    7169: 'GL_FEEDBACK',
    7170: 'GL_SELECT',
    7424: 'GL_FLAT',
    7425: 'GL_SMOOTH',
    7680: 'GL_KEEP',
    7681: 'GL_REPLACE',
    7682: 'GL_INCR',
    7683: 'GL_DECR',
    7936: 'GL_VENDOR',
    7937: 'GL_RENDERER',
    7938: 'GL_VERSION',
    7939: 'GL_EXTENSIONS',
    8192: 'GL_S',
    8193: 'GL_T',
    8194: 'GL_R',
    8195: 'GL_Q',
    8448: 'GL_MODULATE',
    8449: 'GL_DECAL',
    8704: 'GL_TEXTURE_ENV_MODE',
    8705: 'GL_TEXTURE_ENV_COLOR',
    8960: 'GL_TEXTURE_ENV',
    9216: 'GL_EYE_LINEAR',
    9217: 'GL_OBJECT_LINEAR',
    9218: 'GL_SPHERE_MAP',
    9472: 'GL_TEXTURE_GEN_MODE',
    9473: 'GL_OBJECT_PLANE',
    9474: 'GL_EYE_PLANE',
    9728: 'GL_NEAREST',
    9729: 'GL_LINEAR',
    9984: 'GL_NEAREST_MIPMAP_NEAREST',
    9985: 'GL_LINEAR_MIPMAP_NEAREST',
    9986: 'GL_NEAREST_MIPMAP_LINEAR',
    9987: 'GL_LINEAR_MIPMAP_LINEAR',
    10240: 'GL_TEXTURE_MAG_FILTER',
    10241: 'GL_TEXTURE_MIN_FILTER',
    10242: 'GL_TEXTURE_WRAP_S',
    10243: 'GL_TEXTURE_WRAP_T',
    10496: 'GL_CLAMP',
    10497: 'GL_REPEAT',
    10752: 'GL_POLYGON_OFFSET_UNITS',
    10753: 'GL_POLYGON_OFFSET_POINT',
    10754: 'GL_POLYGON_OFFSET_LINE',
    10768: 'GL_R3_G3_B2',
    10784: 'GL_V2F',
    10785: 'GL_V3F',
    10786: 'GL_C4UB_V2F',
    10787: 'GL_C4UB_V3F',
    10788: 'GL_C3F_V3F',
    10789: 'GL_N3F_V3F',
    10790: 'GL_C4F_N3F_V3F',
    10791: 'GL_T2F_V3F',
    10792: 'GL_T4F_V4F',
    10793: 'GL_T2F_C4UB_V3F',
    10794: 'GL_T2F_C3F_V3F',
    10795: 'GL_T2F_N3F_V3F',
    10796: 'GL_T2F_C4F_N3F_V3F',
    10797: 'GL_T4F_C4F_N3F_V4F',
    12288: 'GL_CLIP_PLANE0',
    12289: 'GL_CLIP_PLANE1',
    12290: 'GL_CLIP_PLANE2',
    12291: 'GL_CLIP_PLANE3',
    12292: 'GL_CLIP_PLANE4',
    12293: 'GL_CLIP_PLANE5',
    12294: 'GL_CLIP_DISTANCE6',
    12295: 'GL_CLIP_DISTANCE7',
    16384: 'GL_LIGHT0',
    16385: 'GL_LIGHT1',
    16386: 'GL_LIGHT2',
    16387: 'GL_LIGHT3',
    16388: 'GL_LIGHT4',
    16389: 'GL_LIGHT5',
    16390: 'GL_LIGHT6',
    16391: 'GL_LIGHT7',
    32768: 'GL_ABGR_EXT',
    32769: 'GL_CONSTANT_COLOR_EXT',
    32770: 'GL_ONE_MINUS_CONSTANT_COLOR_EXT',
    32771: 'GL_CONSTANT_ALPHA_EXT',
    32772: 'GL_ONE_MINUS_CONSTANT_ALPHA_EXT',
    32773: 'GL_BLEND_COLOR_EXT',
    32774: 'GL_FUNC_ADD_EXT',
    32775: 'GL_MIN_EXT',
    32776: 'GL_MAX_EXT',
    32777: 'GL_BLEND_EQUATION_RGB',
    32778: 'GL_FUNC_SUBTRACT_EXT',
    32779: 'GL_FUNC_REVERSE_SUBTRACT_EXT',
    32780: 'GL_CMYK_EXT',
    32781: 'GL_CMYKA_EXT',
    32782: 'GL_PACK_CMYK_HINT_EXT',
    32783: 'GL_UNPACK_CMYK_HINT_EXT',
    32784: 'GL_CONVOLUTION_1D_EXT',
    32785: 'GL_CONVOLUTION_2D_EXT',
    32786: 'GL_SEPARABLE_2D_EXT',
    32787: 'GL_CONVOLUTION_BORDER_MODE_EXT',
    32788: 'GL_CONVOLUTION_FILTER_SCALE_EXT',
    32789: 'GL_CONVOLUTION_FILTER_BIAS_EXT',
    32790: 'GL_REDUCE_EXT',
    32791: 'GL_CONVOLUTION_FORMAT_EXT',
    32792: 'GL_CONVOLUTION_WIDTH_EXT',
    32793: 'GL_CONVOLUTION_HEIGHT_EXT',
    32794: 'GL_MAX_CONVOLUTION_WIDTH_EXT',
    32795: 'GL_MAX_CONVOLUTION_HEIGHT_EXT',
    32796: 'GL_POST_CONVOLUTION_RED_SCALE_EXT',
    32797: 'GL_POST_CONVOLUTION_GREEN_SCALE_EXT',
    32798: 'GL_POST_CONVOLUTION_BLUE_SCALE_EXT',
    32799: 'GL_POST_CONVOLUTION_ALPHA_SCALE_EXT',
    32800: 'GL_POST_CONVOLUTION_RED_BIAS_EXT',
    32801: 'GL_POST_CONVOLUTION_GREEN_BIAS_EXT',
    32802: 'GL_POST_CONVOLUTION_BLUE_BIAS_EXT',
    32803: 'GL_POST_CONVOLUTION_ALPHA_BIAS_EXT',
    32804: 'GL_HISTOGRAM_EXT',
    32805: 'GL_PROXY_HISTOGRAM_EXT',
    32806: 'GL_HISTOGRAM_WIDTH_EXT',
    32807: 'GL_HISTOGRAM_FORMAT_EXT',
    32808: 'GL_HISTOGRAM_RED_SIZE_EXT',
    32809: 'GL_HISTOGRAM_GREEN_SIZE_EXT',
    32810: 'GL_HISTOGRAM_BLUE_SIZE_EXT',
    32811: 'GL_HISTOGRAM_ALPHA_SIZE_EXT',
    32812: 'GL_HISTOGRAM_LUMINANCE_SIZE_EXT',
    32813: 'GL_HISTOGRAM_SINK_EXT',
    32814: 'GL_MINMAX_EXT',
    32815: 'GL_MINMAX_FORMAT_EXT',
    32816: 'GL_MINMAX_SINK_EXT',
    32817: 'GL_TABLE_TOO_LARGE_EXT',
    32818: 'GL_UNSIGNED_BYTE_3_3_2_EXT',
    32819: 'GL_UNSIGNED_SHORT_4_4_4_4_EXT',
    32820: 'GL_UNSIGNED_SHORT_5_5_5_1_EXT',
    32821: 'GL_UNSIGNED_INT_8_8_8_8_EXT',
    32822: 'GL_UNSIGNED_INT_10_10_10_2_EXT',
    32823: 'GL_POLYGON_OFFSET_FILL',
    32824: 'GL_POLYGON_OFFSET_FACTOR_EXT',
    32825: 'GL_POLYGON_OFFSET_BIAS_EXT',
    32826: 'GL_RESCALE_NORMAL_EXT',
    32827: 'GL_ALPHA4_EXT',
    32828: 'GL_ALPHA8_EXT',
    32829: 'GL_ALPHA12_EXT',
    32830: 'GL_ALPHA16_EXT',
    32831: 'GL_LUMINANCE4_EXT',
    32832: 'GL_LUMINANCE8_EXT',
    32833: 'GL_LUMINANCE12_EXT',
    32834: 'GL_LUMINANCE16_EXT',
    32835: 'GL_LUMINANCE4_ALPHA4_EXT',
    32836: 'GL_LUMINANCE6_ALPHA2_EXT',
    32837: 'GL_LUMINANCE8_ALPHA8_EXT',
    32838: 'GL_LUMINANCE12_ALPHA4_EXT',
    32839: 'GL_LUMINANCE12_ALPHA12_EXT',
    32840: 'GL_LUMINANCE16_ALPHA16_EXT',
    32841: 'GL_INTENSITY_EXT',
    32842: 'GL_INTENSITY4_EXT',
    32843: 'GL_INTENSITY8_EXT',
    32844: 'GL_INTENSITY12_EXT',
    32845: 'GL_INTENSITY16_EXT',
    32846: 'GL_RGB2_EXT',
    32847: 'GL_RGB4_EXT',
    32848: 'GL_RGB5_EXT',
    32849: 'GL_RGB8_EXT',
    32850: 'GL_RGB10_EXT',
    32851: 'GL_RGB12_EXT',
    32852: 'GL_RGB16_EXT',
    32853: 'GL_RGBA2_EXT',
    32854: 'GL_RGBA4_EXT',
    32855: 'GL_RGB5_A1_EXT',
    32856: 'GL_RGBA8_EXT',
    32857: 'GL_RGB10_A2_EXT',
    32858: 'GL_RGBA12_EXT',
    32859: 'GL_RGBA16_EXT',
    32860: 'GL_TEXTURE_RED_SIZE_EXT',
    32861: 'GL_TEXTURE_GREEN_SIZE_EXT',
    32862: 'GL_TEXTURE_BLUE_SIZE_EXT',
    32863: 'GL_TEXTURE_ALPHA_SIZE_EXT',
    32864: 'GL_TEXTURE_LUMINANCE_SIZE_EXT',
    32865: 'GL_TEXTURE_INTENSITY_SIZE_EXT',
    32866: 'GL_REPLACE_EXT',
    32867: 'GL_PROXY_TEXTURE_1D_EXT',
    32868: 'GL_PROXY_TEXTURE_2D_EXT',
    32869: 'GL_TEXTURE_TOO_LARGE_EXT',
    32870: 'GL_TEXTURE_PRIORITY_EXT',
    32871: 'GL_TEXTURE_RESIDENT_EXT',
    32872: 'GL_TEXTURE_BINDING_1D',
    32873: 'GL_TEXTURE_BINDING_2D',
    32874: 'GL_TEXTURE_BINDING_3D',
    32875: 'GL_PACK_SKIP_IMAGES_EXT',
    32876: 'GL_PACK_IMAGE_HEIGHT_EXT',
    32877: 'GL_UNPACK_SKIP_IMAGES_EXT',
    32878: 'GL_UNPACK_IMAGE_HEIGHT_EXT',
    32879: 'GL_TEXTURE_3D_EXT',
    32880: 'GL_PROXY_TEXTURE_3D_EXT',
    32881: 'GL_TEXTURE_DEPTH_EXT',
    32882: 'GL_TEXTURE_WRAP_R_EXT',
    32883: 'GL_MAX_3D_TEXTURE_SIZE_EXT',
    32884: 'GL_VERTEX_ARRAY_EXT',
    32885: 'GL_NORMAL_ARRAY_EXT',
    32886: 'GL_COLOR_ARRAY_EXT',
    32887: 'GL_INDEX_ARRAY_EXT',
    32888: 'GL_TEXTURE_COORD_ARRAY_EXT',
    32889: 'GL_EDGE_FLAG_ARRAY_EXT',
    32890: 'GL_VERTEX_ARRAY_SIZE_EXT',
    32891: 'GL_VERTEX_ARRAY_TYPE_EXT',
    32892: 'GL_VERTEX_ARRAY_STRIDE_EXT',
    32893: 'GL_VERTEX_ARRAY_COUNT_EXT',
    32894: 'GL_NORMAL_ARRAY_TYPE_EXT',
    32895: 'GL_NORMAL_ARRAY_STRIDE_EXT',
    32896: 'GL_NORMAL_ARRAY_COUNT_EXT',
    32897: 'GL_COLOR_ARRAY_SIZE_EXT',
    32898: 'GL_COLOR_ARRAY_TYPE_EXT',
    32899: 'GL_COLOR_ARRAY_STRIDE_EXT',
    32900: 'GL_COLOR_ARRAY_COUNT_EXT',
    32901: 'GL_INDEX_ARRAY_TYPE_EXT',
    32902: 'GL_INDEX_ARRAY_STRIDE_EXT',
    32903: 'GL_INDEX_ARRAY_COUNT_EXT',
    32904: 'GL_TEXTURE_COORD_ARRAY_SIZE_EXT',
    32905: 'GL_TEXTURE_COORD_ARRAY_TYPE_EXT',
    32906: 'GL_TEXTURE_COORD_ARRAY_STRIDE_EXT',
    32907: 'GL_TEXTURE_COORD_ARRAY_COUNT_EXT',
    32908: 'GL_EDGE_FLAG_ARRAY_STRIDE_EXT',
    32909: 'GL_EDGE_FLAG_ARRAY_COUNT_EXT',
    32910: 'GL_VERTEX_ARRAY_POINTER_EXT',
    32911: 'GL_NORMAL_ARRAY_POINTER_EXT',
    32912: 'GL_COLOR_ARRAY_POINTER_EXT',
    32913: 'GL_INDEX_ARRAY_POINTER_EXT',
    32914: 'GL_TEXTURE_COORD_ARRAY_POINTER_EXT',
    32915: 'GL_EDGE_FLAG_ARRAY_POINTER_EXT',
    32925: 'GL_MULTISAMPLE_EXT',
    32926: 'GL_SAMPLE_ALPHA_TO_MASK_EXT',
    32927: 'GL_SAMPLE_ALPHA_TO_ONE_EXT',
    32928: 'GL_SAMPLE_MASK_EXT',
    32929: 'GL_1PASS_EXT',
    32930: 'GL_2PASS_0_EXT',
    32931: 'GL_2PASS_1_EXT',
    32932: 'GL_4PASS_0_EXT',
    32933: 'GL_4PASS_1_EXT',
    32934: 'GL_4PASS_2_EXT',
    32935: 'GL_4PASS_3_EXT',
    32936: 'GL_SAMPLE_BUFFERS_EXT',
    32937: 'GL_SAMPLES_EXT',
    32938: 'GL_SAMPLE_MASK_VALUE_EXT',
    32939: 'GL_SAMPLE_MASK_INVERT_EXT',
    32940: 'GL_SAMPLE_PATTERN_EXT',
    32945: 'GL_COLOR_MATRIX_SGI',
    32946: 'GL_COLOR_MATRIX_STACK_DEPTH_SGI',
    32947: 'GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI',
    32948: 'GL_POST_COLOR_MATRIX_RED_SCALE_SGI',
    32949: 'GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI',
    32950: 'GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI',
    32951: 'GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI',
    32952: 'GL_POST_COLOR_MATRIX_RED_BIAS_SGI',
    32953: 'GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI',
    32954: 'GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI',
    32955: 'GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI',
    32956: 'GL_TEXTURE_COLOR_TABLE_SGI',
    32957: 'GL_PROXY_TEXTURE_COLOR_TABLE_SGI',
    32959: 'GL_TEXTURE_COMPARE_FAIL_VALUE_ARB',
    32968: 'GL_BLEND_DST_RGB_EXT',
    32969: 'GL_BLEND_SRC_RGB_EXT',
    32970: 'GL_BLEND_DST_ALPHA_EXT',
    32971: 'GL_BLEND_SRC_ALPHA_EXT',
    32972: 'GL_422_EXT',
    32973: 'GL_422_REV_EXT',
    32974: 'GL_422_AVERAGE_EXT',
    32975: 'GL_422_REV_AVERAGE_EXT',
    32976: 'GL_COLOR_TABLE_SGI',
    32977: 'GL_POST_CONVOLUTION_COLOR_TABLE_SGI',
    32978: 'GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI',
    32979: 'GL_PROXY_COLOR_TABLE_SGI',
    32980: 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI',
    32981: 'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI',
    32982: 'GL_COLOR_TABLE_SCALE_SGI',
    32983: 'GL_COLOR_TABLE_BIAS_SGI',
    32984: 'GL_COLOR_TABLE_FORMAT_SGI',
    32985: 'GL_COLOR_TABLE_WIDTH_SGI',
    32986: 'GL_COLOR_TABLE_RED_SIZE_SGI',
    32987: 'GL_COLOR_TABLE_GREEN_SIZE_SGI',
    32988: 'GL_COLOR_TABLE_BLUE_SIZE_SGI',
    32989: 'GL_COLOR_TABLE_ALPHA_SIZE_SGI',
    32990: 'GL_COLOR_TABLE_LUMINANCE_SIZE_SGI',
    32991: 'GL_COLOR_TABLE_INTENSITY_SIZE_SGI',
    32992: 'GL_BGR_EXT',
    32993: 'GL_BGRA_EXT',
    32994: 'GL_COLOR_INDEX1_EXT',
    32995: 'GL_COLOR_INDEX2_EXT',
    32996: 'GL_COLOR_INDEX4_EXT',
    32997: 'GL_COLOR_INDEX8_EXT',
    32998: 'GL_COLOR_INDEX12_EXT',
    32999: 'GL_COLOR_INDEX16_EXT',
    33000: 'GL_MAX_ELEMENTS_VERTICES_EXT',
    33001: 'GL_MAX_ELEMENTS_INDICES_EXT',
    33002: 'GL_PHONG_WIN',
    33003: 'GL_PHONG_HINT_WIN',
    33004: 'GL_FOG_SPECULAR_TEXTURE_WIN',
    33005: 'GL_TEXTURE_INDEX_SIZE_EXT',
    33008: 'GL_CLIP_VOLUME_CLIPPING_HINT_EXT',
    33062: 'GL_POINT_SIZE_MIN_EXT',
    33063: 'GL_POINT_SIZE_MAX_EXT',
    33064: 'GL_POINT_FADE_THRESHOLD_SIZE_EXT',
    33065: 'GL_POINT_DISTANCE_ATTENUATION_ARB',
    33069: 'GL_CLAMP_TO_BORDER_ARB',
    33071: 'GL_CLAMP_TO_EDGE',
    33082: 'GL_TEXTURE_MIN_LOD',
    33083: 'GL_TEXTURE_MAX_LOD',
    33084: 'GL_TEXTURE_BASE_LEVEL',
    33085: 'GL_TEXTURE_MAX_LEVEL',
    33104: 'GL_IGNORE_BORDER_HP',
    33105: 'GL_CONSTANT_BORDER_HP',
    33107: 'GL_REPLICATE_BORDER_HP',
    33108: 'GL_CONVOLUTION_BORDER_COLOR_HP',
    33109: 'GL_IMAGE_SCALE_X_HP',
    33110: 'GL_IMAGE_SCALE_Y_HP',
    33111: 'GL_IMAGE_TRANSLATE_X_HP',
    33112: 'GL_IMAGE_TRANSLATE_Y_HP',
    33113: 'GL_IMAGE_ROTATE_ANGLE_HP',
    33114: 'GL_IMAGE_ROTATE_ORIGIN_X_HP',
    33115: 'GL_IMAGE_ROTATE_ORIGIN_Y_HP',
    33116: 'GL_IMAGE_MAG_FILTER_HP',
    33117: 'GL_IMAGE_MIN_FILTER_HP',
    33118: 'GL_IMAGE_CUBIC_WEIGHT_HP',
    33119: 'GL_CUBIC_HP',
    33120: 'GL_AVERAGE_HP',
    33121: 'GL_IMAGE_TRANSFORM_2D_HP',
    33122: 'GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',
    33123: 'GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',
    33125: 'GL_OCCLUSION_TEST_HP',
    33126: 'GL_OCCLUSION_TEST_RESULT_HP',
    33127: 'GL_TEXTURE_LIGHTING_MODE_HP',
    33128: 'GL_TEXTURE_POST_SPECULAR_HP',
    33129: 'GL_TEXTURE_PRE_SPECULAR_HP',
    33169: 'GL_GENERATE_MIPMAP',
    33170: 'GL_GENERATE_MIPMAP_HINT',
    33189: 'GL_DEPTH_COMPONENT16_ARB',
    33190: 'GL_DEPTH_COMPONENT24_ARB',
    33191: 'GL_DEPTH_COMPONENT32_ARB',
    33192: 'GL_ARRAY_ELEMENT_LOCK_FIRST_EXT',
    33193: 'GL_ARRAY_ELEMENT_LOCK_COUNT_EXT',
    33194: 'GL_CULL_VERTEX_EXT',
    33195: 'GL_CULL_VERTEX_EYE_POSITION_EXT',
    33196: 'GL_CULL_VERTEX_OBJECT_POSITION_EXT',
    33197: 'GL_IUI_V2F_EXT',
    33198: 'GL_IUI_V3F_EXT',
    33199: 'GL_IUI_N3F_V2F_EXT',
    33200: 'GL_IUI_N3F_V3F_EXT',
    33201: 'GL_T2F_IUI_V2F_EXT',
    33202: 'GL_T2F_IUI_V3F_EXT',
    33203: 'GL_T2F_IUI_N3F_V2F_EXT',
    33204: 'GL_T2F_IUI_N3F_V3F_EXT',
    33205: 'GL_INDEX_TEST_EXT',
    33206: 'GL_INDEX_TEST_FUNC_EXT',
    33207: 'GL_INDEX_TEST_REF_EXT',
    33208: 'GL_INDEX_MATERIAL_EXT',
    33209: 'GL_INDEX_MATERIAL_PARAMETER_EXT',
    33210: 'GL_INDEX_MATERIAL_FACE_EXT',
    33236: 'GL_WRAP_BORDER_SUN',
    33237: 'GL_UNPACK_CONSTANT_DATA_SUNX',
    33238: 'GL_TEXTURE_CONSTANT_DATA_SUNX',
    33239: 'GL_TRIANGLE_LIST_SUN',
    33240: 'GL_REPLACEMENT_CODE_SUN',
    33241: 'GL_GLOBAL_ALPHA_SUN',
    33242: 'GL_GLOBAL_ALPHA_FACTOR_SUN',
    33272: 'GL_LIGHT_MODEL_COLOR_CONTROL_EXT',
    33273: 'GL_SINGLE_COLOR_EXT',
    33274: 'GL_SEPARATE_SPECULAR_COLOR_EXT',
    33275: 'GL_SHARED_TEXTURE_PALETTE_EXT',
    33307: 'GL_MAJOR_VERSION',
    33308: 'GL_MINOR_VERSION',
    33309: 'GL_NUM_EXTENSIONS',
    33310: 'GL_CONTEXT_FLAGS',
    33315: 'GL_DEPTH_BUFFER',
    33316: 'GL_STENCIL_BUFFER',
    33317: 'GL_COMPRESSED_RED',
    33318: 'GL_COMPRESSED_RG',
    33584: 'GL_PIXEL_TRANSFORM_2D_EXT',
    33585: 'GL_PIXEL_MAG_FILTER_EXT',
    33586: 'GL_PIXEL_MIN_FILTER_EXT',
    33587: 'GL_PIXEL_CUBIC_WEIGHT_EXT',
    33588: 'GL_CUBIC_EXT',
    33589: 'GL_AVERAGE_EXT',
    33590: 'GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',
    33591: 'GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT',
    33592: 'GL_PIXEL_TRANSFORM_2D_MATRIX_EXT',
    33609: 'GL_FRAGMENT_MATERIAL_EXT',
    33610: 'GL_FRAGMENT_NORMAL_EXT',
    33612: 'GL_FRAGMENT_COLOR_EXT',
    33613: 'GL_ATTENUATION_EXT',
    33614: 'GL_SHADOW_ATTENUATION_EXT',
    33615: 'GL_TEXTURE_APPLICATION_MODE_EXT',
    33616: 'GL_TEXTURE_LIGHT_EXT',
    33617: 'GL_TEXTURE_MATERIAL_FACE_EXT',
    33618: 'GL_TEXTURE_MATERIAL_PARAMETER_EXT',
    33634: 'GL_UNSIGNED_BYTE_2_3_3_REV',
    33635: 'GL_UNSIGNED_SHORT_5_6_5',
    33636: 'GL_UNSIGNED_SHORT_5_6_5_REV',
    33637: 'GL_UNSIGNED_SHORT_4_4_4_4_REV',
    33638: 'GL_UNSIGNED_SHORT_1_5_5_5_REV',
    33639: 'GL_UNSIGNED_INT_8_8_8_8_REV',
    33640: 'GL_UNSIGNED_INT_2_10_10_10_REV',
    33648: 'GL_MIRRORED_REPEAT_ARB',
    33696: 'GL_RGB_S3TC',
    33697: 'GL_RGB4_S3TC',
    33698: 'GL_RGBA_S3TC',
    33699: 'GL_RGBA4_S3TC',
    33776: 'GL_COMPRESSED_RGB_S3TC_DXT1_EXT',
    33777: 'GL_COMPRESSED_RGBA_S3TC_DXT1_EXT',
    33778: 'GL_COMPRESSED_RGBA_S3TC_DXT3_EXT',
    33779: 'GL_COMPRESSED_RGBA_S3TC_DXT5_EXT',
    33780: 'GL_PARALLEL_ARRAYS_INTEL',
    33781: 'GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL',
    33782: 'GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL',
    33783: 'GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL',
    33784: 'GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL',
    33849: 'GL_TANGENT_ARRAY_EXT',
    33850: 'GL_BINORMAL_ARRAY_EXT',
    33851: 'GL_CURRENT_TANGENT_EXT',
    33852: 'GL_CURRENT_BINORMAL_EXT',
    33854: 'GL_TANGENT_ARRAY_TYPE_EXT',
    33855: 'GL_TANGENT_ARRAY_STRIDE_EXT',
    33856: 'GL_BINORMAL_ARRAY_TYPE_EXT',
    33857: 'GL_BINORMAL_ARRAY_STRIDE_EXT',
    33858: 'GL_TANGENT_ARRAY_POINTER_EXT',
    33859: 'GL_BINORMAL_ARRAY_POINTER_EXT',
    33860: 'GL_MAP1_TANGENT_EXT',
    33861: 'GL_MAP2_TANGENT_EXT',
    33862: 'GL_MAP1_BINORMAL_EXT',
    33863: 'GL_MAP2_BINORMAL_EXT',
    33872: 'GL_FOG_COORD_SRC',
    33873: 'GL_FOG_COORDINATE_EXT',
    33874: 'GL_FRAGMENT_DEPTH_EXT',
    33875: 'GL_CURRENT_FOG_COORDINATE_EXT',
    33876: 'GL_FOG_COORD_ARRAY_TYPE',
    33877: 'GL_FOG_COORD_ARRAY_STRIDE',
    33878: 'GL_FOG_COORD_ARRAY_POINTER',
    33879: 'GL_FOG_COORD_ARRAY',
    33880: 'GL_COLOR_SUM_EXT',
    33881: 'GL_CURRENT_SECONDARY_COLOR_EXT',
    33882: 'GL_SECONDARY_COLOR_ARRAY_SIZE_EXT',
    33883: 'GL_SECONDARY_COLOR_ARRAY_TYPE_EXT',
    33884: 'GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT',
    33885: 'GL_SECONDARY_COLOR_ARRAY_POINTER_EXT',
    33886: 'GL_SECONDARY_COLOR_ARRAY_EXT',
    33887: 'GL_CURRENT_RASTER_SECONDARY_COLOR',
    33901: 'GL_ALIASED_POINT_SIZE_RANGE',
    33902: 'GL_ALIASED_LINE_WIDTH_RANGE',
    33936: 'GL_SCREEN_COORDINATES_REND',
    33937: 'GL_INVERTED_SCREEN_W_REND',
    33984: 'GL_TEXTURE0_ARB',
    33985: 'GL_TEXTURE1_ARB',
    33986: 'GL_TEXTURE2_ARB',
    33987: 'GL_TEXTURE3_ARB',
    33988: 'GL_TEXTURE4_ARB',
    33989: 'GL_TEXTURE5_ARB',
    33990: 'GL_TEXTURE6_ARB',
    33991: 'GL_TEXTURE7_ARB',
    33992: 'GL_TEXTURE8_ARB',
    33993: 'GL_TEXTURE9_ARB',
    33994: 'GL_TEXTURE10_ARB',
    33995: 'GL_TEXTURE11_ARB',
    33996: 'GL_TEXTURE12_ARB',
    33997: 'GL_TEXTURE13_ARB',
    33998: 'GL_TEXTURE14_ARB',
    33999: 'GL_TEXTURE15_ARB',
    34000: 'GL_TEXTURE16_ARB',
    34001: 'GL_TEXTURE17_ARB',
    34002: 'GL_TEXTURE18_ARB',
    34003: 'GL_TEXTURE19_ARB',
    34004: 'GL_TEXTURE20_ARB',
    34005: 'GL_TEXTURE21_ARB',
    34006: 'GL_TEXTURE22_ARB',
    34007: 'GL_TEXTURE23_ARB',
    34008: 'GL_TEXTURE24_ARB',
    34009: 'GL_TEXTURE25_ARB',
    34010: 'GL_TEXTURE26_ARB',
    34011: 'GL_TEXTURE27_ARB',
    34012: 'GL_TEXTURE28_ARB',
    34013: 'GL_TEXTURE29_ARB',
    34014: 'GL_TEXTURE30_ARB',
    34015: 'GL_TEXTURE31_ARB',
    34016: 'GL_ACTIVE_TEXTURE_ARB',
    34017: 'GL_CLIENT_ACTIVE_TEXTURE_ARB',
    34018: 'GL_MAX_TEXTURE_UNITS_ARB',
    34019: 'GL_TRANSPOSE_MODELVIEW_MATRIX_ARB',
    34020: 'GL_TRANSPOSE_PROJECTION_MATRIX_ARB',
    34021: 'GL_TRANSPOSE_TEXTURE_MATRIX_ARB',
    34022: 'GL_TRANSPOSE_COLOR_MATRIX_ARB',
    34023: 'GL_SUBTRACT_ARB',
    34024: 'GL_MAX_RENDERBUFFER_SIZE_EXT',
    34025: 'GL_COMPRESSED_ALPHA_ARB',
    34026: 'GL_COMPRESSED_LUMINANCE_ARB',
    34027: 'GL_COMPRESSED_LUMINANCE_ALPHA_ARB',
    34028: 'GL_COMPRESSED_INTENSITY_ARB',
    34029: 'GL_COMPRESSED_RGB_ARB',
    34030: 'GL_COMPRESSED_RGBA_ARB',
    34031: 'GL_TEXTURE_COMPRESSION_HINT_ARB',
    34037: 'GL_TEXTURE_RECTANGLE_ARB',
    34038: 'GL_TEXTURE_BINDING_RECTANGLE_ARB',
    34039: 'GL_PROXY_TEXTURE_RECTANGLE_ARB',
    34040: 'GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB',
    34045: 'GL_MAX_TEXTURE_LOD_BIAS_EXT',
    34046: 'GL_TEXTURE_MAX_ANISOTROPY_EXT',
    34047: 'GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT',
    34048: 'GL_TEXTURE_FILTER_CONTROL_EXT',
    34049: 'GL_TEXTURE_LOD_BIAS_EXT',
    34050: 'GL_MODELVIEW1_STACK_DEPTH_EXT',
    34054: 'GL_MODELVIEW1_MATRIX_EXT',
    34055: 'GL_INCR_WRAP_EXT',
    34056: 'GL_DECR_WRAP_EXT',
    34057: 'GL_VERTEX_WEIGHTING_EXT',
    34058: 'GL_MODELVIEW1_EXT',
    34059: 'GL_CURRENT_VERTEX_WEIGHT_EXT',
    34060: 'GL_VERTEX_WEIGHT_ARRAY_EXT',
    34061: 'GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT',
    34062: 'GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT',
    34063: 'GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT',
    34064: 'GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT',
    34065: 'GL_NORMAL_MAP_EXT',
    34066: 'GL_REFLECTION_MAP_EXT',
    34067: 'GL_TEXTURE_CUBE_MAP_EXT',
    34068: 'GL_TEXTURE_BINDING_CUBE_MAP_EXT',
    34069: 'GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT',
    34070: 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT',
    34071: 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT',
    34072: 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT',
    34073: 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT',
    34074: 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT',
    34075: 'GL_PROXY_TEXTURE_CUBE_MAP_EXT',
    34076: 'GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT',
    34077: 'GL_VERTEX_ARRAY_RANGE_APPLE',
    34078: 'GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE',
    34079: 'GL_VERTEX_ARRAY_STORAGE_HINT_APPLE',
    34081: 'GL_VERTEX_ARRAY_RANGE_POINTER_APPLE',
    34144: 'GL_RED_MIN_CLAMP_INGR',
    34145: 'GL_GREEN_MIN_CLAMP_INGR',
    34146: 'GL_BLUE_MIN_CLAMP_INGR',
    34147: 'GL_ALPHA_MIN_CLAMP_INGR',
    34148: 'GL_RED_MAX_CLAMP_INGR',
    34149: 'GL_GREEN_MAX_CLAMP_INGR',
    34150: 'GL_BLUE_MAX_CLAMP_INGR',
    34151: 'GL_ALPHA_MAX_CLAMP_INGR',
    34152: 'GL_INTERLACE_READ_INGR',
    34160: 'GL_COMBINE_EXT',
    34161: 'GL_COMBINE_RGB_EXT',
    34162: 'GL_COMBINE_ALPHA_EXT',
    34163: 'GL_RGB_SCALE_EXT',
    34164: 'GL_ADD_SIGNED_EXT',
    34165: 'GL_INTERPOLATE_EXT',
    34166: 'GL_CONSTANT_EXT',
    34167: 'GL_PRIMARY_COLOR_EXT',
    34168: 'GL_PREVIOUS_EXT',
    34176: 'GL_SRC0_RGB',
    34177: 'GL_SRC1_RGB',
    34178: 'GL_SRC2_RGB',
    34184: 'GL_SRC0_ALPHA',
    34185: 'GL_SRC1_ALPHA',
    34186: 'GL_SRC2_ALPHA',
    34192: 'GL_OPERAND0_RGB_EXT',
    34193: 'GL_OPERAND1_RGB_EXT',
    34194: 'GL_OPERAND2_RGB_EXT',
    34200: 'GL_OPERAND0_ALPHA_EXT',
    34201: 'GL_OPERAND1_ALPHA_EXT',
    34202: 'GL_OPERAND2_ALPHA_EXT',
    34222: 'GL_PERTURB_EXT',
    34223: 'GL_TEXTURE_NORMAL_EXT',
    34224: 'GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE',
    34225: 'GL_TRANSFORM_HINT_APPLE',
    34226: 'GL_UNPACK_CLIENT_STORAGE_APPLE',
    34229: 'GL_VERTEX_ARRAY_BINDING_APPLE',
    34233: 'GL_YCBCR_422_APPLE',
    34234: 'GL_UNSIGNED_SHORT_8_8_APPLE',
    34235: 'GL_UNSIGNED_SHORT_8_8_REV_APPLE',
    34238: 'GL_STORAGE_CACHED_APPLE',
    34239: 'GL_STORAGE_SHARED_APPLE',
    34240: 'GL_REPLACEMENT_CODE_ARRAY_SUN',
    34241: 'GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN',
    34242: 'GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN',
    34243: 'GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN',
    34244: 'GL_R1UI_V3F_SUN',
    34245: 'GL_R1UI_C4UB_V3F_SUN',
    34246: 'GL_R1UI_C3F_V3F_SUN',
    34247: 'GL_R1UI_N3F_V3F_SUN',
    34248: 'GL_R1UI_C4F_N3F_V3F_SUN',
    34249: 'GL_R1UI_T2F_V3F_SUN',
    34250: 'GL_R1UI_T2F_N3F_V3F_SUN',
    34251: 'GL_R1UI_T2F_C4F_N3F_V3F_SUN',
    34252: 'GL_SLICE_ACCUM_SUN',
    34324: 'GL_QUAD_MESH_SUN',
    34325: 'GL_TRIANGLE_MESH_SUN',
    34336: 'GL_VERTEX_PROGRAM_ARB',
    34338: 'GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB',
    34339: 'GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB',
    34340: 'GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB',
    34341: 'GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB',
    34342: 'GL_CURRENT_VERTEX_ATTRIB_ARB',
    34343: 'GL_PROGRAM_LENGTH_ARB',
    34344: 'GL_PROGRAM_STRING_ARB',
    34350: 'GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB',
    34351: 'GL_MAX_PROGRAM_MATRICES_ARB',
    34368: 'GL_CURRENT_MATRIX_STACK_DEPTH_ARB',
    34369: 'GL_CURRENT_MATRIX_ARB',
    34370: 'GL_VERTEX_PROGRAM_POINT_SIZE_ARB',
    34371: 'GL_VERTEX_PROGRAM_TWO_SIDE_ARB',
    34373: 'GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB',
    34379: 'GL_PROGRAM_ERROR_POSITION_ARB',
    34423: 'GL_PROGRAM_BINDING_ARB',
    34464: 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB',
    34465: 'GL_TEXTURE_COMPRESSED_ARB',
    34466: 'GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB',
    34467: 'GL_COMPRESSED_TEXTURE_FORMATS_ARB',
    34468: 'GL_MAX_VERTEX_UNITS_ARB',
    34469: 'GL_ACTIVE_VERTEX_UNITS_ARB',
    34470: 'GL_WEIGHT_SUM_UNITY_ARB',
    34471: 'GL_VERTEX_BLEND_ARB',
    34472: 'GL_CURRENT_WEIGHT_ARB',
    34473: 'GL_WEIGHT_ARRAY_TYPE_ARB',
    34474: 'GL_WEIGHT_ARRAY_STRIDE_ARB',
    34475: 'GL_WEIGHT_ARRAY_SIZE_ARB',
    34476: 'GL_WEIGHT_ARRAY_POINTER_ARB',
    34477: 'GL_WEIGHT_ARRAY_ARB',
    34478: 'GL_DOT3_RGB_ARB',
    34479: 'GL_DOT3_RGBA_ARB',
    34594: 'GL_MODELVIEW2_ARB',
    34595: 'GL_MODELVIEW3_ARB',
    34596: 'GL_MODELVIEW4_ARB',
    34597: 'GL_MODELVIEW5_ARB',
    34598: 'GL_MODELVIEW6_ARB',
    34599: 'GL_MODELVIEW7_ARB',
    34600: 'GL_MODELVIEW8_ARB',
    34601: 'GL_MODELVIEW9_ARB',
    34602: 'GL_MODELVIEW10_ARB',
    34603: 'GL_MODELVIEW11_ARB',
    34604: 'GL_MODELVIEW12_ARB',
    34605: 'GL_MODELVIEW13_ARB',
    34606: 'GL_MODELVIEW14_ARB',
    34607: 'GL_MODELVIEW15_ARB',
    34608: 'GL_MODELVIEW16_ARB',
    34609: 'GL_MODELVIEW17_ARB',
    34610: 'GL_MODELVIEW18_ARB',
    34611: 'GL_MODELVIEW19_ARB',
    34612: 'GL_MODELVIEW20_ARB',
    34613: 'GL_MODELVIEW21_ARB',
    34614: 'GL_MODELVIEW22_ARB',
    34615: 'GL_MODELVIEW23_ARB',
    34616: 'GL_MODELVIEW24_ARB',
    34617: 'GL_MODELVIEW25_ARB',
    34618: 'GL_MODELVIEW26_ARB',
    34619: 'GL_MODELVIEW27_ARB',
    34620: 'GL_MODELVIEW28_ARB',
    34621: 'GL_MODELVIEW29_ARB',
    34622: 'GL_MODELVIEW30_ARB',
    34623: 'GL_MODELVIEW31_ARB',
    34624: 'GL_DOT3_RGB_EXT',
    34625: 'GL_DOT3_RGBA_EXT',
    34626: 'GL_MIRROR_CLAMP_EXT',
    34627: 'GL_MIRROR_CLAMP_TO_EDGE_EXT',
    34660: 'GL_BUFFER_SIZE_ARB',
    34661: 'GL_BUFFER_USAGE_ARB',
    34664: 'GL_ELEMENT_ARRAY_APPLE',
    34665: 'GL_ELEMENT_ARRAY_TYPE_APPLE',
    34666: 'GL_ELEMENT_ARRAY_POINTER_APPLE',
    34688: 'GL_VERTEX_SHADER_EXT',
    34689: 'GL_VERTEX_SHADER_BINDING_EXT',
    34690: 'GL_OP_INDEX_EXT',
    34691: 'GL_OP_NEGATE_EXT',
    34692: 'GL_OP_DOT3_EXT',
    34693: 'GL_OP_DOT4_EXT',
    34694: 'GL_OP_MUL_EXT',
    34695: 'GL_OP_ADD_EXT',
    34696: 'GL_OP_MADD_EXT',
    34697: 'GL_OP_FRAC_EXT',
    34698: 'GL_OP_MAX_EXT',
    34699: 'GL_OP_MIN_EXT',
    34700: 'GL_OP_SET_GE_EXT',
    34701: 'GL_OP_SET_LT_EXT',
    34702: 'GL_OP_CLAMP_EXT',
    34703: 'GL_OP_FLOOR_EXT',
    34704: 'GL_OP_ROUND_EXT',
    34705: 'GL_OP_EXP_BASE_2_EXT',
    34706: 'GL_OP_LOG_BASE_2_EXT',
    34707: 'GL_OP_POWER_EXT',
    34708: 'GL_OP_RECIP_EXT',
    34709: 'GL_OP_RECIP_SQRT_EXT',
    34710: 'GL_OP_SUB_EXT',
    34711: 'GL_OP_CROSS_PRODUCT_EXT',
    34712: 'GL_OP_MULTIPLY_MATRIX_EXT',
    34713: 'GL_OP_MOV_EXT',
    34714: 'GL_OUTPUT_VERTEX_EXT',
    34715: 'GL_OUTPUT_COLOR0_EXT',
    34716: 'GL_OUTPUT_COLOR1_EXT',
    34717: 'GL_OUTPUT_TEXTURE_COORD0_EXT',
    34718: 'GL_OUTPUT_TEXTURE_COORD1_EXT',
    34719: 'GL_OUTPUT_TEXTURE_COORD2_EXT',
    34720: 'GL_OUTPUT_TEXTURE_COORD3_EXT',
    34721: 'GL_OUTPUT_TEXTURE_COORD4_EXT',
    34722: 'GL_OUTPUT_TEXTURE_COORD5_EXT',
    34723: 'GL_OUTPUT_TEXTURE_COORD6_EXT',
    34724: 'GL_OUTPUT_TEXTURE_COORD7_EXT',
    34725: 'GL_OUTPUT_TEXTURE_COORD8_EXT',
    34726: 'GL_OUTPUT_TEXTURE_COORD9_EXT',
    34727: 'GL_OUTPUT_TEXTURE_COORD10_EXT',
    34728: 'GL_OUTPUT_TEXTURE_COORD11_EXT',
    34729: 'GL_OUTPUT_TEXTURE_COORD12_EXT',
    34730: 'GL_OUTPUT_TEXTURE_COORD13_EXT',
    34731: 'GL_OUTPUT_TEXTURE_COORD14_EXT',
    34732: 'GL_OUTPUT_TEXTURE_COORD15_EXT',
    34733: 'GL_OUTPUT_TEXTURE_COORD16_EXT',
    34734: 'GL_OUTPUT_TEXTURE_COORD17_EXT',
    34735: 'GL_OUTPUT_TEXTURE_COORD18_EXT',
    34736: 'GL_OUTPUT_TEXTURE_COORD19_EXT',
    34737: 'GL_OUTPUT_TEXTURE_COORD20_EXT',
    34738: 'GL_OUTPUT_TEXTURE_COORD21_EXT',
    34739: 'GL_OUTPUT_TEXTURE_COORD22_EXT',
    34740: 'GL_OUTPUT_TEXTURE_COORD23_EXT',
    34741: 'GL_OUTPUT_TEXTURE_COORD24_EXT',
    34742: 'GL_OUTPUT_TEXTURE_COORD25_EXT',
    34743: 'GL_OUTPUT_TEXTURE_COORD26_EXT',
    34744: 'GL_OUTPUT_TEXTURE_COORD27_EXT',
    34745: 'GL_OUTPUT_TEXTURE_COORD28_EXT',
    34746: 'GL_OUTPUT_TEXTURE_COORD29_EXT',
    34747: 'GL_OUTPUT_TEXTURE_COORD30_EXT',
    34748: 'GL_OUTPUT_TEXTURE_COORD31_EXT',
    34749: 'GL_OUTPUT_FOG_EXT',
    34750: 'GL_SCALAR_EXT',
    34751: 'GL_VECTOR_EXT',
    34752: 'GL_MATRIX_EXT',
    34753: 'GL_VARIANT_EXT',
    34754: 'GL_INVARIANT_EXT',
    34755: 'GL_LOCAL_CONSTANT_EXT',
    34756: 'GL_LOCAL_EXT',
    34757: 'GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT',
    34758: 'GL_MAX_VERTEX_SHADER_VARIANTS_EXT',
    34759: 'GL_MAX_VERTEX_SHADER_INVARIANTS_EXT',
    34760: 'GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    34761: 'GL_MAX_VERTEX_SHADER_LOCALS_EXT',
    34762: 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT',
    34763: 'GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT',
    34764: 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    34765: 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT',
    34766: 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT',
    34767: 'GL_VERTEX_SHADER_INSTRUCTIONS_EXT',
    34768: 'GL_VERTEX_SHADER_VARIANTS_EXT',
    34769: 'GL_VERTEX_SHADER_INVARIANTS_EXT',
    34770: 'GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',
    34771: 'GL_VERTEX_SHADER_LOCALS_EXT',
    34772: 'GL_VERTEX_SHADER_OPTIMIZED_EXT',
    34773: 'GL_X_EXT',
    34774: 'GL_Y_EXT',
    34775: 'GL_Z_EXT',
    34776: 'GL_W_EXT',
    34777: 'GL_NEGATIVE_X_EXT',
    34778: 'GL_NEGATIVE_Y_EXT',
    34779: 'GL_NEGATIVE_Z_EXT',
    34780: 'GL_NEGATIVE_W_EXT',
    34781: 'GL_ZERO_EXT',
    34782: 'GL_ONE_EXT',
    34783: 'GL_NEGATIVE_ONE_EXT',
    34784: 'GL_NORMALIZED_RANGE_EXT',
    34785: 'GL_FULL_RANGE_EXT',
    34786: 'GL_CURRENT_VERTEX_EXT',
    34787: 'GL_MVP_MATRIX_EXT',
    34788: 'GL_VARIANT_VALUE_EXT',
    34789: 'GL_VARIANT_DATATYPE_EXT',
    34790: 'GL_VARIANT_ARRAY_STRIDE_EXT',
    34791: 'GL_VARIANT_ARRAY_TYPE_EXT',
    34792: 'GL_VARIANT_ARRAY_EXT',
    34793: 'GL_VARIANT_ARRAY_POINTER_EXT',
    34794: 'GL_INVARIANT_VALUE_EXT',
    34795: 'GL_INVARIANT_DATATYPE_EXT',
    34796: 'GL_LOCAL_CONSTANT_VALUE_EXT',
    34797: 'GL_LOCAL_CONSTANT_DATATYPE_EXT',
    34816: 'GL_STENCIL_BACK_FUNC',
    34817: 'GL_STENCIL_BACK_FAIL',
    34818: 'GL_STENCIL_BACK_PASS_DEPTH_FAIL',
    34819: 'GL_STENCIL_BACK_PASS_DEPTH_PASS',
    34820: 'GL_FRAGMENT_PROGRAM_ARB',
    34821: 'GL_PROGRAM_ALU_INSTRUCTIONS_ARB',
    34822: 'GL_PROGRAM_TEX_INSTRUCTIONS_ARB',
    34823: 'GL_PROGRAM_TEX_INDIRECTIONS_ARB',
    34824: 'GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB',
    34825: 'GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB',
    34826: 'GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB',
    34827: 'GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB',
    34828: 'GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB',
    34829: 'GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB',
    34830: 'GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB',
    34831: 'GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB',
    34832: 'GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB',
    34836: 'GL_RGBA32F_ARB',
    34837: 'GL_RGB32F_ARB',
    34838: 'GL_ALPHA32F_ARB',
    34839: 'GL_INTENSITY32F_ARB',
    34840: 'GL_LUMINANCE32F_ARB',
    34841: 'GL_LUMINANCE_ALPHA32F_ARB',
    34842: 'GL_RGBA16F_ARB',
    34843: 'GL_RGB16F_ARB',
    34844: 'GL_ALPHA16F_ARB',
    34845: 'GL_INTENSITY16F_ARB',
    34846: 'GL_LUMINANCE16F_ARB',
    34847: 'GL_LUMINANCE_ALPHA16F_ARB',
    34848: 'GL_RGBA_FLOAT_MODE_ARB',
    34852: 'GL_MAX_DRAW_BUFFERS_ARB',
    34853: 'GL_DRAW_BUFFER0_ARB',
    34854: 'GL_DRAW_BUFFER1_ARB',
    34855: 'GL_DRAW_BUFFER2_ARB',
    34856: 'GL_DRAW_BUFFER3_ARB',
    34857: 'GL_DRAW_BUFFER4_ARB',
    34858: 'GL_DRAW_BUFFER5_ARB',
    34859: 'GL_DRAW_BUFFER6_ARB',
    34860: 'GL_DRAW_BUFFER7_ARB',
    34861: 'GL_DRAW_BUFFER8_ARB',
    34862: 'GL_DRAW_BUFFER9_ARB',
    34863: 'GL_DRAW_BUFFER10_ARB',
    34864: 'GL_DRAW_BUFFER11_ARB',
    34865: 'GL_DRAW_BUFFER12_ARB',
    34866: 'GL_DRAW_BUFFER13_ARB',
    34867: 'GL_DRAW_BUFFER14_ARB',
    34868: 'GL_DRAW_BUFFER15_ARB',
    34877: 'GL_BLEND_EQUATION_ALPHA_EXT',
    34880: 'GL_MATRIX_PALETTE_ARB',
    34881: 'GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB',
    34882: 'GL_MAX_PALETTE_MATRICES_ARB',
    34883: 'GL_CURRENT_PALETTE_MATRIX_ARB',
    34884: 'GL_MATRIX_INDEX_ARRAY_ARB',
    34885: 'GL_CURRENT_MATRIX_INDEX_ARB',
    34886: 'GL_MATRIX_INDEX_ARRAY_SIZE_ARB',
    34887: 'GL_MATRIX_INDEX_ARRAY_TYPE_ARB',
    34888: 'GL_MATRIX_INDEX_ARRAY_STRIDE_ARB',
    34889: 'GL_MATRIX_INDEX_ARRAY_POINTER_ARB',
    34890: 'GL_TEXTURE_DEPTH_SIZE_ARB',
    34891: 'GL_DEPTH_TEXTURE_MODE_ARB',
    34892: 'GL_TEXTURE_COMPARE_MODE_ARB',
    34893: 'GL_TEXTURE_COMPARE_FUNC_ARB',
    34894: 'GL_COMPARE_R_TO_TEXTURE_ARB',
    34913: 'GL_POINT_SPRITE_ARB',
    34914: 'GL_COORD_REPLACE_ARB',
    34916: 'GL_QUERY_COUNTER_BITS_ARB',
    34917: 'GL_CURRENT_QUERY_ARB',
    34918: 'GL_QUERY_RESULT_ARB',
    34919: 'GL_QUERY_RESULT_AVAILABLE_ARB',
    34921: 'GL_MAX_VERTEX_ATTRIBS_ARB',
    34922: 'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB',
    34929: 'GL_MAX_TEXTURE_COORDS_ARB',
    34930: 'GL_MAX_TEXTURE_IMAGE_UNITS_ARB',
    34932: 'GL_PROGRAM_ERROR_STRING_ARB',
    34933: 'GL_PROGRAM_FORMAT_ASCII_ARB',
    34934: 'GL_PROGRAM_FORMAT_ARB',
    34960: 'GL_DEPTH_BOUNDS_TEST_EXT',
    34961: 'GL_DEPTH_BOUNDS_EXT',
    34962: 'GL_ARRAY_BUFFER_ARB',
    34963: 'GL_ELEMENT_ARRAY_BUFFER_ARB',
    34964: 'GL_ARRAY_BUFFER_BINDING_ARB',
    34965: 'GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB',
    34966: 'GL_VERTEX_ARRAY_BUFFER_BINDING_ARB',
    34967: 'GL_NORMAL_ARRAY_BUFFER_BINDING_ARB',
    34968: 'GL_COLOR_ARRAY_BUFFER_BINDING_ARB',
    34969: 'GL_INDEX_ARRAY_BUFFER_BINDING_ARB',
    34970: 'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB',
    34971: 'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB',
    34972: 'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB',
    34973: 'GL_FOG_COORD_ARRAY_BUFFER_BINDING',
    34974: 'GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB',
    34975: 'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB',
    34976: 'GL_PROGRAM_INSTRUCTIONS_ARB',
    34977: 'GL_MAX_PROGRAM_INSTRUCTIONS_ARB',
    34978: 'GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB',
    34979: 'GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB',
    34980: 'GL_PROGRAM_TEMPORARIES_ARB',
    34981: 'GL_MAX_PROGRAM_TEMPORARIES_ARB',
    34982: 'GL_PROGRAM_NATIVE_TEMPORARIES_ARB',
    34983: 'GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB',
    34984: 'GL_PROGRAM_PARAMETERS_ARB',
    34985: 'GL_MAX_PROGRAM_PARAMETERS_ARB',
    34986: 'GL_PROGRAM_NATIVE_PARAMETERS_ARB',
    34987: 'GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB',
    34988: 'GL_PROGRAM_ATTRIBS_ARB',
    34989: 'GL_MAX_PROGRAM_ATTRIBS_ARB',
    34990: 'GL_PROGRAM_NATIVE_ATTRIBS_ARB',
    34991: 'GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB',
    34992: 'GL_PROGRAM_ADDRESS_REGISTERS_ARB',
    34993: 'GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB',
    34994: 'GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',
    34995: 'GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB',
    34996: 'GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB',
    34997: 'GL_MAX_PROGRAM_ENV_PARAMETERS_ARB',
    34998: 'GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB',
    34999: 'GL_TRANSPOSE_CURRENT_MATRIX_ARB',
    35000: 'GL_READ_ONLY_ARB',
    35001: 'GL_WRITE_ONLY_ARB',
    35002: 'GL_READ_WRITE_ARB',
    35003: 'GL_BUFFER_ACCESS_ARB',
    35004: 'GL_BUFFER_MAPPED_ARB',
    35005: 'GL_BUFFER_MAP_POINTER_ARB',
    35008: 'GL_MATRIX0_ARB',
    35009: 'GL_MATRIX1_ARB',
    35010: 'GL_MATRIX2_ARB',
    35011: 'GL_MATRIX3_ARB',
    35012: 'GL_MATRIX4_ARB',
    35013: 'GL_MATRIX5_ARB',
    35014: 'GL_MATRIX6_ARB',
    35015: 'GL_MATRIX7_ARB',
    35016: 'GL_MATRIX8_ARB',
    35017: 'GL_MATRIX9_ARB',
    35018: 'GL_MATRIX10_ARB',
    35019: 'GL_MATRIX11_ARB',
    35020: 'GL_MATRIX12_ARB',
    35021: 'GL_MATRIX13_ARB',
    35022: 'GL_MATRIX14_ARB',
    35023: 'GL_MATRIX15_ARB',
    35024: 'GL_MATRIX16_ARB',
    35025: 'GL_MATRIX17_ARB',
    35026: 'GL_MATRIX18_ARB',
    35027: 'GL_MATRIX19_ARB',
    35028: 'GL_MATRIX20_ARB',
    35029: 'GL_MATRIX21_ARB',
    35030: 'GL_MATRIX22_ARB',
    35031: 'GL_MATRIX23_ARB',
    35032: 'GL_MATRIX24_ARB',
    35033: 'GL_MATRIX25_ARB',
    35034: 'GL_MATRIX26_ARB',
    35035: 'GL_MATRIX27_ARB',
    35036: 'GL_MATRIX28_ARB',
    35037: 'GL_MATRIX29_ARB',
    35038: 'GL_MATRIX30_ARB',
    35039: 'GL_MATRIX31_ARB',
    35040: 'GL_STREAM_DRAW_ARB',
    35041: 'GL_STREAM_READ_ARB',
    35042: 'GL_STREAM_COPY_ARB',
    35044: 'GL_STATIC_DRAW_ARB',
    35045: 'GL_STATIC_READ_ARB',
    35046: 'GL_STATIC_COPY_ARB',
    35048: 'GL_DYNAMIC_DRAW_ARB',
    35049: 'GL_DYNAMIC_READ_ARB',
    35050: 'GL_DYNAMIC_COPY_ARB',
    35051: 'GL_PIXEL_PACK_BUFFER_EXT',
    35052: 'GL_PIXEL_UNPACK_BUFFER_EXT',
    35053: 'GL_PIXEL_PACK_BUFFER_BINDING_EXT',
    35055: 'GL_PIXEL_UNPACK_BUFFER_BINDING_EXT',
    35069: 'GL_VERTEX_ATTRIB_ARRAY_INTEGER',
    35071: 'GL_MAX_ARRAY_TEXTURE_LAYERS',
    35076: 'GL_MIN_PROGRAM_TEXEL_OFFSET',
    35077: 'GL_MAX_PROGRAM_TEXEL_OFFSET',
    35088: 'GL_STENCIL_TEST_TWO_SIDE_EXT',
    35089: 'GL_ACTIVE_STENCIL_FACE_EXT',
    35090: 'GL_MIRROR_CLAMP_TO_BORDER_EXT',
    35092: 'GL_SAMPLES_PASSED_ARB',
    35094: 'GL_GEOMETRY_VERTICES_OUT',
    35095: 'GL_GEOMETRY_INPUT_TYPE',
    35096: 'GL_GEOMETRY_OUTPUT_TYPE',
    35098: 'GL_CLAMP_VERTEX_COLOR_ARB',
    35099: 'GL_CLAMP_FRAGMENT_COLOR_ARB',
    35100: 'GL_CLAMP_READ_COLOR_ARB',
    35101: 'GL_FIXED_ONLY_ARB',
    35200: 'GL_INTERLACE_OML',
    35201: 'GL_INTERLACE_READ_OML',
    35202: 'GL_FORMAT_SUBSAMPLE_24_24_OML',
    35203: 'GL_FORMAT_SUBSAMPLE_244_244_OML',
    35204: 'GL_PACK_RESAMPLE_OML',
    35205: 'GL_UNPACK_RESAMPLE_OML',
    35206: 'GL_RESAMPLE_REPLICATE_OML',
    35207: 'GL_RESAMPLE_ZERO_FILL_OML',
    35208: 'GL_RESAMPLE_AVERAGE_OML',
    35209: 'GL_RESAMPLE_DECIMATE_OML',
    35338: 'GL_DRAW_PIXELS_APPLE',
    35339: 'GL_FENCE_APPLE',
    35632: 'GL_FRAGMENT_SHADER_ARB',
    35633: 'GL_VERTEX_SHADER_ARB',
    35648: 'GL_PROGRAM_OBJECT_ARB',
    35656: 'GL_SHADER_OBJECT_ARB',
    35657: 'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB',
    35658: 'GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB',
    35659: 'GL_MAX_VARYING_FLOATS_ARB',
    35660: 'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB',
    35661: 'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB',
    35662: 'GL_OBJECT_TYPE_ARB',
    35663: 'GL_SHADER_TYPE',
    35664: 'GL_FLOAT_VEC2_ARB',
    35665: 'GL_FLOAT_VEC3_ARB',
    35666: 'GL_FLOAT_VEC4_ARB',
    35667: 'GL_INT_VEC2_ARB',
    35668: 'GL_INT_VEC3_ARB',
    35669: 'GL_INT_VEC4_ARB',
    35670: 'GL_BOOL_ARB',
    35671: 'GL_BOOL_VEC2_ARB',
    35672: 'GL_BOOL_VEC3_ARB',
    35673: 'GL_BOOL_VEC4_ARB',
    35674: 'GL_FLOAT_MAT2_ARB',
    35675: 'GL_FLOAT_MAT3_ARB',
    35676: 'GL_FLOAT_MAT4_ARB',
    35677: 'GL_SAMPLER_1D_ARB',
    35678: 'GL_SAMPLER_2D_ARB',
    35679: 'GL_SAMPLER_3D_ARB',
    35680: 'GL_SAMPLER_CUBE_ARB',
    35681: 'GL_SAMPLER_1D_SHADOW_ARB',
    35682: 'GL_SAMPLER_2D_SHADOW_ARB',
    35683: 'GL_SAMPLER_2D_RECT_ARB',
    35684: 'GL_SAMPLER_2D_RECT_SHADOW_ARB',
    35685: 'GL_FLOAT_MAT2x3',
    35686: 'GL_FLOAT_MAT2x4',
    35687: 'GL_FLOAT_MAT3x2',
    35688: 'GL_FLOAT_MAT3x4',
    35689: 'GL_FLOAT_MAT4x2',
    35690: 'GL_FLOAT_MAT4x3',
    35712: 'GL_OBJECT_DELETE_STATUS_ARB',
    35713: 'GL_OBJECT_COMPILE_STATUS_ARB',
    35714: 'GL_OBJECT_LINK_STATUS_ARB',
    35715: 'GL_VALIDATE_STATUS',
    35716: 'GL_OBJECT_INFO_LOG_LENGTH_ARB',
    35717: 'GL_OBJECT_ATTACHED_OBJECTS_ARB',
    35718: 'GL_OBJECT_ACTIVE_UNIFORMS_ARB',
    35719: 'GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB',
    35720: 'GL_SHADER_SOURCE_LENGTH',
    35721: 'GL_OBJECT_ACTIVE_ATTRIBUTES_ARB',
    35722: 'GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB',
    35723: 'GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB',
    35724: 'GL_SHADING_LANGUAGE_VERSION_ARB',
    35725: 'GL_CURRENT_PROGRAM',
    35738: 'GL_IMPLEMENTATION_COLOR_READ_TYPE_OES',
    35739: 'GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES',
    35856: 'GL_TEXTURE_RED_TYPE_ARB',
    35857: 'GL_TEXTURE_GREEN_TYPE_ARB',
    35858: 'GL_TEXTURE_BLUE_TYPE_ARB',
    35859: 'GL_TEXTURE_ALPHA_TYPE_ARB',
    35860: 'GL_TEXTURE_LUMINANCE_TYPE_ARB',
    35861: 'GL_TEXTURE_INTENSITY_TYPE_ARB',
    35862: 'GL_TEXTURE_DEPTH_TYPE_ARB',
    35863: 'GL_UNSIGNED_NORMALIZED_ARB',
    35864: 'GL_TEXTURE_1D_ARRAY',
    35865: 'GL_PROXY_TEXTURE_1D_ARRAY',
    35866: 'GL_TEXTURE_2D_ARRAY',
    35867: 'GL_PROXY_TEXTURE_2D_ARRAY',
    35868: 'GL_TEXTURE_BINDING_1D_ARRAY',
    35869: 'GL_TEXTURE_BINDING_2D_ARRAY',
    35881: 'GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS',
    35882: 'GL_TEXTURE_BUFFER',
    35883: 'GL_MAX_TEXTURE_BUFFER_SIZE',
    35884: 'GL_TEXTURE_BINDING_BUFFER',
    35885: 'GL_TEXTURE_BUFFER_DATA_STORE_BINDING',
    35886: 'GL_TEXTURE_BUFFER_FORMAT',
    35898: 'GL_R11F_G11F_B10F',
    35899: 'GL_UNSIGNED_INT_10F_11F_11F_REV',
    35901: 'GL_RGB9_E5',
    35902: 'GL_UNSIGNED_INT_5_9_9_9_REV',
    35903: 'GL_TEXTURE_SHARED_SIZE',
    35904: 'GL_SRGB',
    35905: 'GL_SRGB8',
    35906: 'GL_SRGB_ALPHA',
    35907: 'GL_SRGB8_ALPHA8',
    35908: 'GL_SLUMINANCE_ALPHA',
    35909: 'GL_SLUMINANCE8_ALPHA8',
    35910: 'GL_SLUMINANCE',
    35911: 'GL_SLUMINANCE8',
    35912: 'GL_COMPRESSED_SRGB',
    35913: 'GL_COMPRESSED_SRGB_ALPHA',
    35914: 'GL_COMPRESSED_SLUMINANCE',
    35915: 'GL_COMPRESSED_SLUMINANCE_ALPHA',
    35958: 'GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH',
    35967: 'GL_TRANSFORM_FEEDBACK_BUFFER_MODE',
    35968: 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS',
    35971: 'GL_TRANSFORM_FEEDBACK_VARYINGS',
    35972: 'GL_TRANSFORM_FEEDBACK_BUFFER_START',
    35973: 'GL_TRANSFORM_FEEDBACK_BUFFER_SIZE',
    35975: 'GL_PRIMITIVES_GENERATED',
    35976: 'GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN',
    35977: 'GL_RASTERIZER_DISCARD',
    35978: 'GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS',
    35979: 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS',
    35980: 'GL_INTERLEAVED_ATTRIBS',
    35981: 'GL_SEPARATE_ATTRIBS',
    35982: 'GL_TRANSFORM_FEEDBACK_BUFFER',
    35983: 'GL_TRANSFORM_FEEDBACK_BUFFER_BINDING',
    36000: 'GL_POINT_SPRITE_COORD_ORIGIN',
    36001: 'GL_LOWER_LEFT',
    36002: 'GL_UPPER_LEFT',
    36003: 'GL_STENCIL_BACK_REF',
    36004: 'GL_STENCIL_BACK_VALUE_MASK',
    36005: 'GL_STENCIL_BACK_WRITEMASK',
    36006: 'GL_FRAMEBUFFER_BINDING_EXT',
    36007: 'GL_RENDERBUFFER_BINDING_EXT',
    36048: 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT',
    36049: 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT',
    36050: 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT',
    36051: 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT',
    36052: 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT',
    36053: 'GL_FRAMEBUFFER_COMPLETE_EXT',
    36054: 'GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT',
    36055: 'GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT',
    36056: 'GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT',
    36057: 'GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT',
    36058: 'GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT',
    36059: 'GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT',
    36060: 'GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT',
    36061: 'GL_FRAMEBUFFER_UNSUPPORTED_EXT',
    36063: 'GL_MAX_COLOR_ATTACHMENTS_EXT',
    36064: 'GL_COLOR_ATTACHMENT0_EXT',
    36065: 'GL_COLOR_ATTACHMENT1_EXT',
    36066: 'GL_COLOR_ATTACHMENT2_EXT',
    36067: 'GL_COLOR_ATTACHMENT3_EXT',
    36068: 'GL_COLOR_ATTACHMENT4_EXT',
    36069: 'GL_COLOR_ATTACHMENT5_EXT',
    36070: 'GL_COLOR_ATTACHMENT6_EXT',
    36071: 'GL_COLOR_ATTACHMENT7_EXT',
    36072: 'GL_COLOR_ATTACHMENT8_EXT',
    36073: 'GL_COLOR_ATTACHMENT9_EXT',
    36074: 'GL_COLOR_ATTACHMENT10_EXT',
    36075: 'GL_COLOR_ATTACHMENT11_EXT',
    36076: 'GL_COLOR_ATTACHMENT12_EXT',
    36077: 'GL_COLOR_ATTACHMENT13_EXT',
    36078: 'GL_COLOR_ATTACHMENT14_EXT',
    36079: 'GL_COLOR_ATTACHMENT15_EXT',
    36096: 'GL_DEPTH_ATTACHMENT_EXT',
    36128: 'GL_STENCIL_ATTACHMENT_EXT',
    36160: 'GL_FRAMEBUFFER_EXT',
    36161: 'GL_RENDERBUFFER_EXT',
    36162: 'GL_RENDERBUFFER_WIDTH_EXT',
    36163: 'GL_RENDERBUFFER_HEIGHT_EXT',
    36164: 'GL_RENDERBUFFER_INTERNAL_FORMAT_EXT',
    36166: 'GL_STENCIL_INDEX1_EXT',
    36167: 'GL_STENCIL_INDEX4_EXT',
    36168: 'GL_STENCIL_INDEX8_EXT',
    36169: 'GL_STENCIL_INDEX16_EXT',
    36176: 'GL_RENDERBUFFER_RED_SIZE_EXT',
    36177: 'GL_RENDERBUFFER_GREEN_SIZE_EXT',
    36178: 'GL_RENDERBUFFER_BLUE_SIZE_EXT',
    36179: 'GL_RENDERBUFFER_ALPHA_SIZE_EXT',
    36180: 'GL_RENDERBUFFER_DEPTH_SIZE_EXT',
    36181: 'GL_RENDERBUFFER_STENCIL_SIZE_EXT',
    36208: 'GL_RGBA32UI',
    36209: 'GL_RGB32UI',
    36214: 'GL_RGBA16UI',
    36215: 'GL_RGB16UI',
    36220: 'GL_RGBA8UI',
    36221: 'GL_RGB8UI',
    36226: 'GL_RGBA32I',
    36227: 'GL_RGB32I',
    36232: 'GL_RGBA16I',
    36233: 'GL_RGB16I',
    36238: 'GL_RGBA8I',
    36239: 'GL_RGB8I',
    36244: 'GL_RED_INTEGER',
    36245: 'GL_GREEN_INTEGER',
    36246: 'GL_BLUE_INTEGER',
    36247: 'GL_ALPHA_INTEGER',
    36248: 'GL_RGB_INTEGER',
    36249: 'GL_RGBA_INTEGER',
    36250: 'GL_BGR_INTEGER',
    36251: 'GL_BGRA_INTEGER',
    36263: 'GL_FRAMEBUFFER_ATTACHMENT_LAYERED',
    36264: 'GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS',
    36288: 'GL_SAMPLER_1D_ARRAY',
    36289: 'GL_SAMPLER_2D_ARRAY',
    36290: 'GL_SAMPLER_BUFFER',
    36291: 'GL_SAMPLER_1D_ARRAY_SHADOW',
    36292: 'GL_SAMPLER_2D_ARRAY_SHADOW',
    36293: 'GL_SAMPLER_CUBE_SHADOW',
    36294: 'GL_UNSIGNED_INT_VEC2',
    36295: 'GL_UNSIGNED_INT_VEC3',
    36296: 'GL_UNSIGNED_INT_VEC4',
    36297: 'GL_INT_SAMPLER_1D',
    36298: 'GL_INT_SAMPLER_2D',
    36299: 'GL_INT_SAMPLER_3D',
    36300: 'GL_INT_SAMPLER_CUBE',
    36301: 'GL_INT_SAMPLER_2D_RECT',
    36302: 'GL_INT_SAMPLER_1D_ARRAY',
    36303: 'GL_INT_SAMPLER_2D_ARRAY',
    36304: 'GL_INT_SAMPLER_BUFFER',
    36305: 'GL_UNSIGNED_INT_SAMPLER_1D',
    36306: 'GL_UNSIGNED_INT_SAMPLER_2D',
    36307: 'GL_UNSIGNED_INT_SAMPLER_3D',
    36308: 'GL_UNSIGNED_INT_SAMPLER_CUBE',
    36309: 'GL_UNSIGNED_INT_SAMPLER_2D_RECT',
    36310: 'GL_UNSIGNED_INT_SAMPLER_1D_ARRAY',
    36311: 'GL_UNSIGNED_INT_SAMPLER_2D_ARRAY',
    36312: 'GL_UNSIGNED_INT_SAMPLER_BUFFER',
    36313: 'GL_GEOMETRY_SHADER',
    36319: 'GL_MAX_GEOMETRY_UNIFORM_COMPONENTS',
    36320: 'GL_MAX_GEOMETRY_OUTPUT_VERTICES',
    36321: 'GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS',
    36371: 'GL_QUERY_WAIT',
    36372: 'GL_QUERY_NO_WAIT',
    36373: 'GL_QUERY_BY_REGION_WAIT',
    36374: 'GL_QUERY_BY_REGION_NO_WAIT',
    36752: 'GL_RED_SNORM',
    36753: 'GL_RG_SNORM',
    36754: 'GL_RGB_SNORM',
    36755: 'GL_RGBA_SNORM',
    36756: 'GL_R8_SNORM',
    36757: 'GL_RG8_SNORM',
    36758: 'GL_RGB8_SNORM',
    36759: 'GL_RGBA8_SNORM',
    36760: 'GL_R16_SNORM',
    36761: 'GL_RG16_SNORM',
    36762: 'GL_RGB16_SNORM',
    36763: 'GL_RGBA16_SNORM',
    36764: 'GL_SIGNED_NORMALIZED',
    36765: 'GL_PRIMITIVE_RESTART',
    36766: 'GL_PRIMITIVE_RESTART_INDEX',
    37151: 'GL_BUFFER_ACCESS_FLAGS',
    37152: 'GL_BUFFER_MAP_LENGTH',
    37153: 'GL_BUFFER_MAP_OFFSET',
    37154: 'GL_MAX_VERTEX_OUTPUT_COMPONENTS',
    37155: 'GL_MAX_GEOMETRY_INPUT_COMPONENTS',
    37156: 'GL_MAX_GEOMETRY_OUTPUT_COMPONENTS',
    37157: 'GL_MAX_FRAGMENT_INPUT_COMPONENTS',
    37158: 'GL_CONTEXT_PROFILE_MASK'}

constant_regex = re.compile(r'(?<![.\w])\d+(?![.\w])(?! /\*GL_)')

def expand_constant(match):
    constant = match.group(0)
    try:
        if int(constant) not in constant_map: return constant
    except Exception,e:
        return constant
    constant = int(constant)
    return '%d /*%s*/' % (constant, constant_map[constant])

def annotate_constants(code):
    return constant_regex.sub(expand_constant, code)

def annotate_file(filename):
    code = file(filename,'r').read()
    if 'import org.lwjgl.opengl.' in code:
        code = annotate_constants(code)
        file(filename,'w').write(code)

if __name__ == '__main__' and len(sys.argv) > 1:
    for arg in sys.argv[1:]:
        annotate_file(arg)
